<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Header
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2021 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined('_JEXEC') or die;

class ModNobossheaderHelper {
    /**
	 * Prepara dados e estilos dos botoes de acao
     * 
     * @param       Object      $buttonsActions     Dados dos botoes
	 *
	 * @return  void
	 */
    public static function prepareActionsButtons($buttonsActions){
        $app = JFactory::getApplication();
        
        // pega o template vinculado a pagina
        $tmpl = $app->getTemplate(true);
        // pega os parametros do template
        $tmplParams = $tmpl->params;
        // pega a cor primaria setada nos parametros do template
        $tmplPrimaryColor = $tmplParams->get('primary_color');
        // pega a cor secundaria setada nos parametros do template
        $tmplSecondaryColor = $tmplParams->get('secondary_color');

        // Filtra os highlights para remover os items despublicados
        $nowDate = date('Y-m-d H:i:s');
        $buttonsActions = (object) array_filter( (array) $buttonsActions, function($items) use ($nowDate){
            // Não está publicado o point
            if ($items->published != '1'){
                return false;
            }
            // Data de publicacao de inicio esta definida e eh maior do que a data atual
            else if ((($items->publish_in != '') && ($items->publish_in != '0000-00-00 00:00:00')) &&
            (strtotime($items->publish_in) >= strtotime($nowDate))){
                return false;
            }
            // Data de publicacao de fim esta definida e eh menor do que a data atual
            else if ((($items->publish_down != '') && ($items->publish_down != '0000-00-00 00:00:00')) &&
            (strtotime($nowDate) >= strtotime($items->publish_down))){
                return false;
            }
            return true;
        });

        // Percorre os botoes a exibir
        foreach ($buttonsActions as $key => $item) {
            // guarda o target do link
            $item->link_target = $item->link_target ? "_blank" : "_self";
            // valida se o tipo de link é externo
            if($item->link_option == "external") {
                $item->link = $item->link_external;
                // valida se o tipo de link é interno
            } else {
                $menuItem = $item->link_internal;
                // Obtem o path do item de menu inicial
                if ($menuItem > 0){
                    $item->link = NoBossUtilUrl::getUrlItemMenu($menuItem);
                }
            }

            $buttonCustomization = (object) json_decode($item->button_customization);

            // Setado para exibir como botao
            if($item->show_as_button){
                // Variaveis para estilo
                $item->linkStyle = "";
                $item->linkStyleMobile = "";

                // Variaveis para estilos hover
                $item->linkStyleHover = "";

                // Fonte do texto
                if(isset($buttonCustomization->buttons_font)){
                    $item->linkStyle .= NoBossUtilFonts::importNobossfontlist($buttonCustomization->buttons_font);
                }
                if(isset($buttonCustomization->buttons_text_transform)){
                    $item->linkStyle .= " text-transform: {$buttonCustomization->buttons_text_transform};";
                }

                if(!isset($buttonCustomization->buttons_text_size)){
                    $buttonCustomization->buttons_text_size = '12';
                }

                // Tamanho da fonte do texto
                $buttonsSize = (isset($buttonCustomization->buttons_text_size)) ? $buttonCustomization->buttons_text_size : '14';
                if(!empty($buttonsSize)){
                    $buttonsSizeEm = $buttonsSize/16;
                    $item->linkStyle .= " font-size: {$buttonsSize}px; font-size: {$buttonsSizeEm}em;";
                }

                if (!isset($buttonCustomization->buttons_text_size_mobile)){
                    $buttonCustomization->buttons_text_size_mobile = $buttonCustomization->buttons_text_size;
                }
                
                // Tamanho da fonte do mobile
                $buttonsSizeEmMobile = $buttonCustomization->buttons_text_size_mobile/16;
                $item->linkStyleMobile .= " font-size: {$buttonCustomization->buttons_text_size_mobile}px !important; font-size: {$buttonsSizeEmMobile}em !important;";

                // Cor do texto
                $buttonCustomization->buttons_text_color = !empty($buttonCustomization->buttons_text_color) ? $buttonCustomization->buttons_text_color : 'rgba(255, 255, 255, 1)';

                // Cor do texto mobile
                $buttonCustomization->buttons_text_color_mobile = !empty($buttonCustomization->buttons_text_color_mobile) ? $buttonCustomization->buttons_text_color_mobile : $buttonCustomization->buttons_text_color;
                
                // Cor de fundo
                $buttonCustomization->buttons_background_color = !empty($buttonCustomization->buttons_background_color) ? $buttonCustomization->buttons_background_color : 'rgb(122 122 122)';

                // Cor de fundo mobile
                $buttonCustomization->buttons_background_color_mobile = !empty($buttonCustomization->buttons_background_color_mobile) ? $buttonCustomization->buttons_background_color_mobile : $buttonCustomization->buttons_background_color;

                // Cor da borda
                $buttonCustomization->buttons_border_color = !empty($buttonCustomization->buttons_border_color) ? $buttonCustomization->buttons_border_color : $tmplPrimaryColor;

                // Cor da borda
                $buttonCustomization->buttons_border_color_mobile = !empty($buttonCustomization->buttons_border_color_mobile) ? $buttonCustomization->buttons_border_color_mobile : $buttonCustomization->buttons_border_color;

                // Cor do texto no hover
                $buttonCustomization->buttons_hover_text_color = !empty($buttonCustomization->buttons_hover_text_color) ? $buttonCustomization->buttons_hover_text_color : 'rgba(255, 255, 255, 1)';

                // Cor de fundo no hover
                $buttonCustomization->buttons_background_hover_color = !empty($buttonCustomization->buttons_background_hover_color) ? $buttonCustomization->buttons_background_hover_color : 'rgb(88 88 88)';

                // Cor da borda no hover
                $buttonCustomization->buttons_hover_border_color = !empty($buttonCustomization->buttons_hover_border_color) ? $buttonCustomization->buttons_hover_border_color : $tmplSecondaryColor;

                // Padding
                $item->linkStyle .= !(empty($buttonCustomization->items_inner_space)) ? ' padding: '. implode(' ', $buttonCustomization->items_inner_space) . '; ' : " padding: 10px 30px 10px 30px;";
                
                // Padding mobile
                $item->linkStyleMobile .= !(empty($buttonCustomization->items_inner_space_mobile)) ? ' padding: '. implode(' ', $buttonCustomization->items_inner_space_mobile) . ' !important; ' : '';

                // Margin
                $item->linkStyle .= !(empty($buttonCustomization->items_outer_space)) ? ' margin: '. implode(' ', $buttonCustomization->items_outer_space) . '; ' : '';

                // Margin mobile
                $item->linkStyleMobile .= !(empty($buttonCustomization->items_outer_space_mobile)) ? ' margin: '. implode(' ', $buttonCustomization->items_outer_space_mobile) . ' !important; ' : '';

                if(!isset($buttonCustomization->buttons_style)){
                    $buttonCustomization->buttons_style = 'squared-button';
                }

                if(!isset($buttonCustomization->buttons_border_radius_size)){
                    $buttonCustomization->buttons_border_radius_size = '30';
                }

                // Tipo de botao
                switch ($buttonCustomization->buttons_style) {
                    // Botão quadrado
                    case 'squared-button':
                        $item->linkStyle .= "color: {$buttonCustomization->buttons_text_color}; background-color: {$buttonCustomization->buttons_background_color};";
                        $item->linkStyleHover .=  " color: {$buttonCustomization->buttons_hover_text_color} !important; background-color: {$buttonCustomization->buttons_background_hover_color} !important;";
                        
                        // Mobile 
                        $item->linkStyleMobile .= "color: {$buttonCustomization->buttons_text_color_mobile}; background-color: {$buttonCustomization->buttons_background_color_mobile};";
                        break;

                    // Botão arredondado
                    case 'rounded-button':
                        $item->linkStyle .= "color: {$buttonCustomization->buttons_text_color}; background-color: {$buttonCustomization->buttons_background_color}; border-radius: {$buttonCustomization->buttons_border_radius_size}px;";
                        $item->linkStyleHover .= " color: {$buttonCustomization->buttons_hover_text_color} !important; background-color: {$buttonCustomization->buttons_background_hover_color} !important;";

                        // Mobile 
                        $item->linkStyleMobile .= "color: {$buttonCustomization->buttons_text_color_mobile}; background-color: {$buttonCustomization->buttons_background_color_mobile};";

                        if(!empty($buttonCustomization->buttons_border_radius_size_mobile)){
                            $item->linkStyleMobile .= " border-radius: {$buttonCustomization->buttons_border_radius_size_mobile}px;";
                        }
                        break;
                   
                    // Botão transparente quadrado
                    case 'ghost-squared-button':
                        $item->linkStyle .= "background-color: transparent; border: 2px solid; color: {$buttonCustomization->buttons_text_color}; border-color: {$buttonCustomization->buttons_border_color};";
                        $item->linkStyleHover .= "color: {$buttonCustomization->buttons_hover_text_color} !important; border-color: {$buttonCustomization->buttons_hover_border_color} !important; background-color: {$buttonCustomization->buttons_background_hover_color} !important;";

                        // Mobile 
                        $item->linkStyleMobile .= "background-color: transparent; border: 2px solid; color: {$buttonCustomization->buttons_text_color_mobile}; border-color: {$buttonCustomization->buttons_border_color_mobile};";
                        break;
                   
                    // Botão transparente arredondado
                    case 'ghost-rounded-button':
                        $item->linkStyle .= "background-color: transparent; border: 2px solid; color: {$buttonCustomization->buttons_text_color}; border-color: {$buttonCustomization->buttons_border_color}; border-radius: {$buttonCustomization->buttons_border_radius_size}px;";
                        $item->linkStyleHover .= "color: {$buttonCustomization->buttons_hover_text_color} !important; border-color: {$buttonCustomization->buttons_hover_border_color} !important; background-color: {$buttonCustomization->buttons_background_hover_color} !important;";

                        // Mobile 
                        $item->linkStyleMobile .= "background-color: transparent; border: 2px solid; color: {$buttonCustomization->buttons_text_color_mobile}; border-color: {$buttonCustomization->buttons_border_color_mobile}; border-radius: {$buttonCustomization->buttons_border_radius_size_mobile}px;";
                        break;

                    default:
                        $item->linkStyle .= "color: {$buttonCustomization->buttons_text_color};";

                        // Mobile 
                        $item->linkStyleMobile .= "color: {$buttonCustomization->buttons_text_color_mobile};";
                        break;
                }
            }

            // Setado para exibir como link
            else{
                $linkCustomization = (object) json_decode($item->link_customization);

                // armazena o estilo do link 
                $item->linkStyle = "";
                $item->linkStyleMobile = "";

                // armazena o estilo do link para o hover
                $item->linkStyleHover = "";
                
                // Fonte
                $item->linkStyle .= NoBossUtilFonts::importNobossfontlist($linkCustomization->link_font);
                $item->linkStyle .= " text-transform: {$linkCustomization->link_text_transform};";

                // Tamanho da fonte
                $linkSize = $linkCustomization->link_text_size;
                if(!empty($linkSize)){
                    $linkSizeEm = $linkSize/16;
                    $item->linkStyle .= " font-size: {$linkSize}px; font-size: {$linkSizeEm}em;";
                }

                /* // @TODO: o IF abaixo foi colocado temporariamente para manter compatibilidade com quem ainda nao editou apos novo campo
                * -> Remover apos out/2020 (6 meses apos mudanca)
                */
                if (!isset($linkCustomization->link_text_size_mobile)){
                    $linkCustomization->link_text_size_mobile = $linkCustomization->link_text_size;
                }

                // Tamanho da fonte mobile
                $linkSizeMobile = $linkCustomization->link_text_size_mobile;
                if(!empty($linkSize)){
                    $linkSizeEmMobile = $linkSizeMobile/16;
                    $item->linkStyleMobile .= " font-size: {$linkSizeMobile}px; font-size: {$linkSizeEmMobile}em;";
                }
                
                // Cor do texto
                $linkCustomization->link_text_color = !empty($linkCustomization->link_text_color) ? $linkCustomization->link_text_color : $tmplPrimaryColor;
                $item->linkStyle .= " color: {$linkCustomization->link_text_color};";
                
                // Cor do texto mobile
                $linkCustomization->link_text_color_mobile = !empty($linkCustomization->link_text_color_mobile) ? $linkCustomization->link_text_color_mobile : $linkCustomization->link_text_color;
                $item->linkStyleMobile .= " color: {$linkCustomization->link_text_color_mobile};";

                // Cor do texto no hover
                $linkCustomization->link_hover_text_color = !empty($linkCustomization->link_hover_text_color) ? $linkCustomization->link_hover_text_color : $tmplSecondaryColor;
                $item->linkHoverColor = " color: {$linkCustomization->link_hover_text_color} !important; ";

                // Espacamento
                if(isset($linkCustomization->link_space)){
                    $item->linkStyle .= !(empty($linkCustomization->link_space)) ? ' margin: '. implode(' ', $linkCustomization->link_space) . '; ' : '';
                }

                // Espacamento mobile
                if(isset($linkCustomization->link_space_mobile)){
                    $item->linkStyleMobile .= !(empty($linkCustomization->link_space_mobile)) ? ' margin: '. implode(' ', $linkCustomization->link_space_mobile) . '; ' : ' margin: '. implode(' ', $linkCustomization->link_space) . '; ';
                }

                // Setado para exibir icone
                if($item->show_icon){
                    $item->iconStyle = "";
                    // armazena o estilo do link para o mobile
                    $item->iconStyleMobile = "";

                    $iconSize = $linkCustomization->icons_size;
                    if(!empty($iconSize)){
                        $iconSizeEm = $iconSize/16;
                        $item->iconStyle .= " font-size: {$iconSize}px; font-size: {$iconSizeEm}em;";
                    }

                    if(!empty($linkCustomization->icons_color)){
                        $item->iconStyle .= "color: {$linkCustomization->icons_color};";
                    }

                    if(!empty($linkCustomization->icons_color_hover)){
                        $item->iconHoverColor = "color: {$linkCustomization->icons_color_hover} !important;";
                    }

                    if(!empty($linkCustomization->icons_color_mobile)){
                        $item->iconStyleMobile .= "color: {$linkCustomization->icons_color_mobile} !important;";
                    }

                    $iconSizeMobile = $linkCustomization->icons_size_mobile;
                    if(!empty($iconSizeMobile)){
                        $iconSizeMobileEm = $iconSizeMobile/16;
                        $item->iconStyleMobile .= " font-size: {$iconSizeMobile}px; font-size: {$iconSizeMobileEm}em !important;";
                    }
                }
            }
        }

        return $buttonsActions;
    }

    /**
	 * Prepara dados e estilos dos menus
     * 
     * @param       Object      $menuParams            Dados do menu
     * @param       Object      $menuCustomization     Dados do menu
     * @param       String      $barDescription        Identificador da barra que esta chamando (slimBar, mainBar, secondaryBar)
	 *
	 * @return  void
	 */
    public static function prepareActionsMenu($menuParams, $menuCustomization, $barDescription){
        $app = JFactory::getApplication();
        
        // pega o template vinculado a pagina
        $tmpl = $app->getTemplate(true);
        // pega os parametros do template
        $tmplParams = $tmpl->params;
        // pega a cor primaria setada nos parametros do template
        $tmplPrimaryColor = $tmplParams->get('primary_color');
        // pega a cor secundaria setada nos parametros do template
        $tmplSecondaryColor = $tmplParams->get('secondary_color');

        // estilo de texto do menu
        $menuParams->menuTextStyle = "";
        $menuParams->menuTextStyle .= NoBossUtilFonts::importNobossfontlist($menuCustomization->menu_text_font);
        $menuParams->menuTextStyle .= "text-transform: {$menuCustomization->menu_text_transform};";

        // pega a cor definida no modulo ou a cor primaria do template
        $menuCustomization->menu_text_color = !empty($menuCustomization->menu_text_color) ? $menuCustomization->menu_text_color : $tmplPrimaryColor;
        $menuParams->menuTextStyle .= "color: {$menuCustomization->menu_text_color};";
        $menuParams->menuTextSize = $menuCustomization->menu_text_size;

        // tamanho da fonte no menu
        if(!empty($menuParams->menuTextSize)){
            $menuParams->menuTextSizeEm = $menuParams->menuTextSize/16;
            $menuParams->menuTextStyle .= "font-size: {$menuParams->menuTextSize}px; font-size: {$menuParams->menuTextSizeEm}em;";
        }

        // pega a cor definida no modulo ou a cor secundaria do template
        $menuCustomization->menu_active_text_color = !empty($menuCustomization->menu_active_text_color) ? $menuCustomization->menu_active_text_color : $tmplSecondaryColor;

        // personalizacao do hover / item ativo
        $menuParams->menuTextStyleHover = !empty($menuCustomization->menu_active_text_color) ? " color: {$menuCustomization->menu_active_text_color} !important;" : "";

        // verifica se tem cor de fundo no hover
        if($menuCustomization->menu_active_show_background){
            // pega a cor definida no modulo ou a cor secundaria do template
            $menuCustomization->menu_active_background_color = !empty($menuCustomization->menu_active_background_color) ? $menuCustomization->menu_active_background_color : '#fff';
            $menuParams->menuTextStyleHover .= !empty($menuCustomization->menu_active_background_color) ? "background-color: {$menuCustomization->menu_active_background_color};" : "background-color: transparent;";
        }

        // verifica se tem borda no hover
        if($menuCustomization->menu_active_show_border){
            // pega a cor definida no modulo ou a cor secundaria do template
            $menuCustomization->menu_active_border_color = !empty($menuCustomization->menu_active_border_color) ? $menuCustomization->menu_active_border_color : '#fff';
        
            // Barra secundaria
            if ($barDescription == 'secondaryBar'){
                $menuParams->menuTextBorder = " position: absolute; bottom: -0.75em; width: 50%; display:block; border-style: solid; border-width: " . implode(" ", $menuCustomization->menu_active_border) . "; border-color: {$menuCustomization->menu_active_border_color};";
            }
            // Nao eh barra secundaria
            else{
                $menuParams->menuTextStyleHover .= "border-style: solid; border-width: " . implode(" ", $menuCustomization->menu_active_border) . "; border-color: {$menuCustomization->menu_active_border_color};";
            }
        }

        // espacamento interno e externo
        $menuParams->menuInnerSpace = ' padding: ' . implode(' ', $menuCustomization->menu_items_inner_space) . '; ';
        $menuParams->menuOuterSpace = ' padding: ' . implode(' ', $menuCustomization->menu_items_outer_space) . '; ';

        // estilo do submenu 
        // pega a cor definida no modulo ou a cor primaria do template
        $menuCustomization->submenu_background_color = !empty($menuCustomization->submenu_background_color) ? $menuCustomization->submenu_background_color : '#fff'; 
        $menuParams->submenuBackgroundColor = !empty($menuCustomization->submenu_background_color) ? "background-color: {$menuCustomization->submenu_background_color}; " : "background-color: transparent;";

        // estilo de texto do submenu
        $menuParams->submenuTextStyle = "";
        $menuParams->submenuTextStyle .= NoBossUtilFonts::importNobossfontlist($menuCustomization->submenu_text_font);
        $menuParams->submenuTextStyle .= "text-transform: {$menuCustomization->submenu_text_transform};";

        // pega a cor definida no modulo ou a cor primaria do template
        $menuCustomization->submenu_text_color = !empty($menuCustomization->submenu_text_color) ? $menuCustomization->submenu_text_color : $menuCustomization->menu_text_color;
        $menuParams->submenuTextStyle .= "color: {$menuCustomization->submenu_text_color};";

        $menuParams->submenuTextStyle .= "text-align: {$menuCustomization->submenu_text_alignment};";
        $menuParams->submenuTextSize = $menuCustomization->submenu_text_size;

        // tamanho da fonte no submenu
        if(!empty($menuParams->submenuTextSize)){
            $menuParams->submenuTextSizeEm = $menuParams->submenuTextSize/16;
            $menuParams->submenuTextStyle .= "font-size: {$menuParams->submenuTextSize}px;";
        }

        // pega a cor definida no modulo ou a cor secundaria do template
        $menuCustomization->submenu_active_text_color = !empty($menuCustomization->submenu_active_text_color) ? $menuCustomization->submenu_active_text_color : $tmplSecondaryColor;

        // personalizacao do hover / item ativo
        $menuParams->submenuTextStyleHover = !empty($menuCustomization->submenu_active_text_color) ? " color: {$menuCustomization->submenu_active_text_color} !important;" : "";
        // verifica se tem cor de fundo no hover
        if($menuCustomization->submenu_active_show_background){
            // pega a cor definida no modulo ou a cor secundaria do template
            $menuCustomization->submenu_active_background_color = !empty($menuCustomization->submenu_active_background_color) ? $menuCustomization->submenu_active_background_color : '#fff';
            $menuParams->submenuTextStyleHover .= !empty($menuCustomization->submenu_active_background_color) ? "background-color: {$menuCustomization->submenu_active_background_color};" : "";
        }

        // verifica se tem borda no hover
        if($menuCustomization->submenu_active_show_border){
            // pega a cor definida no modulo ou a cor secundaria do template
            $menuCustomization->submenu_active_border_color = !empty($menuCustomization->submenu_active_border_color) ? $menuCustomization->submenu_active_border_color : '#fff';
            $menuParams->submenuTextStyleHover .= "border-style: solid; border-width: " . implode(" ", $menuCustomization->submenu_active_border) . "; border-color: {$menuCustomization->submenu_active_border_color};";
        }

        // espacamento interno e externo
        $menuParams->submenuInnerSpace = ' padding: ' . implode(' ', $menuCustomization->submenu_items_inner_space) . '; ';
        $menuParams->submenuOuterSpace = ' padding: ' . implode(' ', $menuCustomization->submenu_items_outer_space) . '; ';

        $return = new \stdClass();

        $return->menuParams = $menuParams;
        $return->menuCustomization = $menuCustomization;

        return $return;
    }

    /**
	 * Verifica se No Boss Library esta instalada no site e caso nao esteja, forca uma atualizacao e recarrega a pagina
     * 
     * OBS: essa acao eh necessaria para contornar problema em atualizacoes da library no processo do Joomla que as vezes mantem ela removida
	 *
	 * @return  void
	 */
    public static function checkLibraryInstallation(){
        // Library da No Boss nao localizada: inicia instalacao forcada da library
        if(!JFolder::exists(JPATH_LIBRARIES.'/noboss')) {
            try {
                // Adiciona diretorio de models do componente installer do Joomla
                JModelLegacy::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_installer/models');
                // Instancia model de extensoes
                $modelInstaller = JModelLegacy::getInstance('install', 'InstallerModel');
                $input = JFactory::getApplication()->input;
                
                // Versao macro do Joomla (ex: 5)
                $joomlaVersion = substr(JVERSION, 0, 1);

                $urlXml = "https://www.nobossextensions.com/repository/extras/nobosslibrary/xml.xml";
                $urlInstallation = "https://www.nobossextensions.com/en/installation/nobosslibrary/";

                // Objeto com conteudo do arquivo XML que controla as atualizacoes da extensao
                $xmlUpdates = simplexml_load_file($urlXml);

                // Percorre todas versoes de update do xml
                for($i=0; $i < count($xmlUpdates->update); $i++){
                    // Possui atributo que identifica a versao da extensao
                    if(isset($xmlUpdates->update[$i]->attributes()['nbjoomla'])){
                        // Obtem qual eh a versao do Joomla (ex: 'current', '3', '4') no item de update do XML
                        $xmlUpdateJoomlaVersion = $xmlUpdates->update[$i]->attributes()['nbjoomla'];

                        // Item eh da mesma versao que estamos da extensao: adiciona versao do joomla na url de instalacao
                        if($xmlUpdateJoomlaVersion == $joomlaVersion){
                            $urlInstallation .= "joomla{$joomlaVersion}/";
                        }
                    }
                }
                
                // Seta para utilizar metodo de instalacao via url
                $input->set('installtype', 'url');
                // Seta a url de instalacao da library
                $input->set('install_url', $urlInstallation);

                // Executa metodo de instalacao
                $modelInstaller->install();
            } catch (Exception $e) {
                // Nao tem tratamento de erro pq o Joomla joga diversas vezes a falta de permissoes como erro sendo que ocorreu tudo certo
            }

            // Library foi instalada com sucesso
            if(JFolder::exists(JPATH_LIBRARIES.'/noboss')) {
                // Recarrega a pagina
                header("Refresh:0");
                exit;
            }
            else{
                return false;
            }
        }
        return true;
    }

    /**
	 * Funcao executada antes de qualquer acao de update do joomla
     * 
	 * @param   JUpdate       $update  An update definition
     * @param   JTableUpdate  $table   The update instance from the database
	 */
    public static function prepareUpdate($update, $table){
        jimport('noboss.util.installscript');

        // Token da licenca
        $token = str_replace('token=', '', $update->get('extra_query'));

        if (method_exists('NoBossUtilInstallscript','updateLicenseIsValid')){
            // Busca no servidor da No Boss se extensao possui permissao para update
            $return = NoBossUtilInstallscript::updateLicenseIsValid($token);
            
            // Token nao localizado
            if ($return == 'INVALID_TOKEN'){
                $msg = "<b>There are problems with the extension license:</b> <br /><br /> &bull; Your extension token was not found on the No Boss Extensions platform. <br /><br />";
                JFactory::getApplication()->enqueueMessage($msg, 'error');
                return false;
            }
            // Extensao nao possui suporte valido
            else if($return == 'INVALID'){
                $msg = "<b>License with expired update period:</b> <br /><br /> &bull; To update the extension, it is necessary to renew the license support period. <br /> &bull; You can renew the support time by accessing the tab called 'License' available within the edition of any extension registration. <br /><br />";
                JFactory::getApplication()->enqueueMessage($msg, 'error');
                return false;
            }
        }
    }
}
