<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Header
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2021 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined('_JEXEC') or die;

// Inclui helper
JLoader::register('ModNobossheaderHelper', __DIR__ . '/helper.php');

// Helper language p/ J4
use Joomla\Module\Languages\Site\Helper\LanguagesHelper;

// Verifica se no boss library esta instalada: se ainda nao estiver, tenta instalar e se ainda nao der retorna false
if(!ModNobossheaderHelper::checkLibraryInstallation()){
    return;
}

$app = JFactory::getApplication();

// Obtem dados do menu ativo
$menu = $app->getMenu();    
$menuActive = $menu->getActive();

// Joomla 3
if(version_compare(JVERSION, '4', '<')){
    JLoader::register('ModLanguagesHelper', JPATH_SITE . '/modules/mod_languages/helper.php');

    // Pega a listagem dos idiomas
    $list = ModLanguagesHelper::getList($params);
}
// Joomla a partir do 4
else{
    // Pega a listagem dos idiomas
    $list = LanguagesHelper::getList($params);
}

// pega o template vinculado a pagina
$tmpl = $app->getTemplate(true);
// pega os parametros do template
$tmplParams = $tmpl->params;
// pega a cor primaria setada nos parametros do template
$tmplPrimaryColor = $tmplParams->get('primary_color');
// pega a cor secundaria setada nos parametros do template
$tmplSecondaryColor = $tmplParams->get('secondary_color');

// Parametro com nome do modulo nao esta definido
if (!isset($module->name)){
    $module->name = str_replace('mod_', '', $module->module);
}
$moduleName = $module->name;
$extensionName = "mod_" . $module->name;

$doc = JFactory::getDocument();
jimport('noboss.util.loadextensionassets');
jimport('noboss.util.fonts');
jimport('noboss.util.url');

// armazena o tema escolhido
$theme = json_decode($params->get('theme'))->theme;

// Nome da modal de personalizacao mobile
$mobileModalXml = "mobile_customization";
// Objeto com os parametros da modal de personalizacao mobile
$mobileModal = json_decode($params->get($mobileModalXml));
if(empty($mobileModal)){
    $mobileModal = new \stdClass;
}


// TODO: INICIO - BARRA SLIM

// name da modal de personalizacao do topo
$slimBarModalXml = "slim_bar_customization";
// objeto com os parametros definidos na modal de personalizacao do topo
$slimBarModal = json_decode($params->get($slimBarModalXml));

$showSlimBar = $params->get('show_slim_bar');

// Barra slim setada para ser exibida
if(isset($showSlimBar) && $showSlimBar){
    // estilo da galeria de video em resolucoes nao mobile
    $slimBarStyle = "";
    
    // armazena o estilo do espaçamento interno na variável que é colocada no elemento mais externo
    $slimBarStyle .= ' padding: ' . implode(' ', $slimBarModal->items_inner_space) . '; ';
    // armazena o estilo do espaçamento externo na variável que é colocada no elemento mais externo
    $slimBarStyle .= ' margin: ' . implode(' ', $slimBarModal->items_outer_space) . '; ';
    
    // verifica se a largura do conteudo ta sendo definida manualmente
    // 1: é manual, então exibe container
    // 0: é full width
    if($slimBarModal->content_display_mode){
        // largura do conteudo
        $itemColumns = !empty($slimBarModal->content_columns) ? "nb-lg-{$slimBarModal->content_columns} nb-md-{$slimBarModal->content_columns} nb-sm-{$slimBarModal->content_columns} nb-xs-12" : "";
    }
    // pega a cor definida no modulo ou a cor primaria do template
    $slimBarModal->background_color = !empty($slimBarModal->background_color) ? $slimBarModal->background_color : $tmplPrimaryColor;
    $slimBarStyle .= !empty($slimBarModal->background_color) ? "background-color: {$slimBarModal->background_color};" : "";
    
    // guarda os itens que serao exibidos em cada posicao
    $slimBarPos1 = $slimBarModal->position_1;
    $slimBarPos2 = $slimBarModal->position_2;
    $slimBarPos3 = $slimBarModal->position_3;
    // alinhamento do item do centro
    $slimBarPos2Alignment = $slimBarModal->position_2_alignment;
    
    // pega os itens cadastrados no subform
    $menuItems = $params->get('slim_bar_position'); 

    // Menu da barra slim setado para ser exibida no mobile
    $slimMobile = $params->get('slim_bar_display_mobile', 0); 

    if(!empty($menuItems)){
        // Obtem modulo de menu para exibir
        $slimBarModuleMenu = JModuleHelper::getModules($menuItems);
    }    
    
    if (!empty($slimBarModuleMenu)){
        // renderiza o módulo para devolver o html 
        $slimBarModuloMenuHtml = JModuleHelper::renderModule( $slimBarModuleMenu[0] );   
    // -------------------------------- MENU DESKTOP ----------------------------------------- // 
        $slimBarMenuParams = new \stdClass;
    
        $slimBarMenuParams->sideMenuParams = new \stdClass;

        $slimBarMenuShowMenuAsBurger = $slimBarModal->show_menu_burguer;
        if(isset($slimBarMenuShowMenuAsBurger) && $slimBarMenuShowMenuAsBurger){
            if($slimBarPos1 === 'menu' || $slimBarPos2 === 'menu' ){
                $slimBarWrapperClass = 'left';
                $slimBarHasSideMenu = true;
            }else if($slimBarPos3 === 'menu'){
                $slimBarWrapperClass = 'right';
                $slimBarHasSideMenu = true;
            }else{
                $slimBarHasSideMenu = false;
            }


            $slimBarMenuParams->sideMenuParams->style = "";
            $slimBarMenuParams->sideMenuParams->style .= ' width: '.$slimBarModal->menu_burger_width.'%; ';
            $slimBarMenuParams->sideMenuParams->style .= ' background-color: '.$slimBarModal->menu_burger_background_color.'; ';
    
            $slimBarMenuParams->sideMenuParams->headerStyle = "";
            $slimBarMenuParams->sideMenuParams->headerStyle .= ' background-color: '.$slimBarModal->menu_burger_header_background_color.'; ';
            $slimBarMenuParams->sideMenuParams->headerStyle .= ' height: '.$slimBarModal->menu_burger_header_height.'%; ';
            $slimBarMenuParams->sideMenuParams->closeButtonColor = ' color: '.$slimBarModal->menu_burger_close_icon_color.'; ';
    
            $slimBarMenuParams->sideMenuParams->itemsBorder = "";
            if($slimBarModal->menu_burger_items_show_border){
                $slimBarMenuParams->sideMenuParams->itemsBorder .= 'border-style: solid; border-color: '.$slimBarModal->menu_burger_items_border_color .'; border-width: '.implode(" ",$slimBarModal->menu_burger_items_border) . '; ';
    
            }

            // Estilo do ícone de menu 
            $slimBarMenuParams->sideMenuParams->desktopMenuIconStyle = "";
            
            // pega a cor definida no modulo ou a cor primaria do template
            $slimBarModal->desktop_menu_icon_color = !empty($slimBarModal->desktop_menu_icon_color) ? $slimBarModal->desktop_menu_icon_color : $tmplPrimaryColor;
            $slimBarMenuParams->sideMenuParams->desktopMenuIconStyle .= "color: {$slimBarModal->desktop_menu_icon_color} !important;";
            $desktopMenuIconSize = $slimBarModal->desktop_menu_icon_size;
            if(!empty($desktopMenuIconSize)){
                $desktopMenuIconSizeEm = $desktopMenuIconSize/16;
                $slimBarMenuParams->sideMenuParams->desktopMenuIconStyle .= " font-size: {$desktopMenuIconSize}px; font-size: {$desktopMenuIconSizeEm}em !important;";
            }
            $slimBarMenuParams->sideMenuParams->desktopMenuIconStyle .= ' padding: ' . implode(' ', $slimBarModal->desktop_icons_space) . '; ';    
        }
    
        // Prepara os dados do menu para exibicao
        $menuReturn = ModNobossheaderHelper::prepareActionsMenu($slimBarMenuParams, $slimBarModal, 'slimBar');
        $slimBarMenuParams = $menuReturn->menuParams;
        $slimBarModal = $menuReturn->menuCustomization;
    
        // -------------------------------- MENU DESKTOP ----------------------------------------- // 
    }
    
    // inicia a flag de exibir cada item adicional como false
    $slimBarShowActionLinks = $params->get('slim_bar_show_action_links');

    // Botoes / links de acao a exibir
    if($slimBarShowActionLinks){
        $slimBarShowActionLinks = true;
        // pega os itens cadastrados
        $slimBarLinks = $params->get("slim_bar_action_links");
        // Prepara os dados dos botoes para exibicao
        $slimBarLinks = ModNobossheaderHelper::prepareActionsButtons($slimBarLinks);
      
    }

    $slimBarShowSocialMedia = $params->get('slim_bar_show_social_media');
    $slimBarShowSocialMediaOnMobile = $params->get('slim_bar_social_media_show_on_mobile');
    if($slimBarShowSocialMedia){
        // pega as redes sociais cadastradas
        $socialMediaItems = $params->get("slim_bar_social_media");
        // decoda os parametros da modal de personalizacao 
        $socialMediaCustomization = json_decode($params->get("slim_bar_social_media_customization"));


        

        // variável utilizada para armazenar os estilos dos ícones de rede social
        $socialMediaStyle = "";
        $socialMediaHasBorder = $socialMediaCustomization->show_icons_border ? 'has-border' : '';

        if(!empty($socialMediaCustomization->icons_color)){
            $socialMediaStyle .= "color: {$socialMediaCustomization->icons_color};";
        }

        $socialMediaStyle .= $socialMediaCustomization->show_icons_background ? " background-color: {$socialMediaCustomization->icons_background}; " : '';
        
        if($socialMediaCustomization->show_icons_border){
            $borderSize = isset($socialMediaCustomization->border_size) ? implode(' ', $socialMediaCustomization->border_size) : '5px';
            $socialMediaStyle .= $socialMediaCustomization->show_icons_border ? " border-width: {$borderSize}; border-style: solid; border-color: {$socialMediaCustomization->icons_border_color}; " : '';
        }

        $socialMediaStyle .= $socialMediaCustomization->show_icons_border_radius ? " border-radius:  {$socialMediaCustomization->icons_border_radius}px; " : '';
        $iconsSize = $socialMediaCustomization->icons_size;
        // configura o tamanho do icone
        if(!empty($iconsSize)){
            $iconsSizeEm = $iconsSize/16;
            $socialMediaStyle .= "font-size: {$iconsSize}px; font-size: {$iconsSizeEm}em;";
        }

        // estilo para ícones no hover 
        $socialMediaStyleHover = "";
        if($socialMediaCustomization->enable_icons_hover){
            $socialMediaCustomization->icons_color_hover = !empty($socialMediaCustomization->icons_color_hover) ? $socialMediaCustomization->icons_color_hover : $tmplSecondaryColor;
            $socialMediaStyleHover .= "color: {$socialMediaCustomization->icons_color_hover} !important; ";
            $socialMediaStyleHover .= $socialMediaCustomization->show_icons_background ? "background-color: {$socialMediaCustomization->icons_background_hover} !important; ": '';
            $socialMediaStyleHover .= $socialMediaCustomization->show_icons_border ? "border-color: {$socialMediaCustomization->icons_border_color_hover} !important; " : '';
        }

        $socialMediaStyleMobile="";

        $iconsSizeMobile = $socialMediaCustomization->icons_size_mobile;
        // configura o tamanho do icone
        if(!empty($iconsSizeMobile)){
            $iconsSizeMobileEm = $iconsSizeMobile/16;
            $socialMediaStyleMobile .= "font-size: {$iconsSizeMobile}px; font-size: {$iconsSizeMobileEm}em;";
        }

        if(isset($socialMediaCustomization->social_media_inner_space)){
            $socialMediaStyle .= ' padding: ' . implode(' ', $socialMediaCustomization->social_media_inner_space) . '; ';
        }

        if(isset($socialMediaCustomization->social_media_inner_space_mobile)){
            $socialMediaStyleMobile .= 'padding: ' . implode(' ', $socialMediaCustomization->social_media_inner_space_mobile) . ' !important; ';
        }

        if(isset($socialMediaCustomization->social_media_outer_space)){
            $socialMediaStyle .= ' margin: ' . implode(' ', $socialMediaCustomization->social_media_outer_space) . '; ';
        }

        if(isset($socialMediaCustomization->social_media_outer_space_mobile)){
            $socialMediaStyleMobile .= 'margin: ' . implode(' ', $socialMediaCustomization->social_media_outer_space_mobile) . ' !important;';
        }
    }

    $slimBarLogoConfig = $params->get("slim_bar_logo");
    $slimBarLogoConfig = (array)$slimBarLogoConfig;
    $slimBarLogoConfig = reset($slimBarLogoConfig);
    $slimBarLogoConfig = (object)$slimBarLogoConfig;

    $slimBarLogoParams = new \stdClass;
    $slimBarLogoParams->logoConfig = $slimBarLogoConfig;

    $slimBarShowLogo = $slimBarLogoConfig->show_logo;

    // verifica se o logo deve ser exibido
    if($slimBarShowLogo){
        // objeto da modal de personazalicao do logo
        $logoCustomization = json_decode($slimBarLogoConfig->logo_customization);
        
        // verifica se o logo eh em forma de texto
        if($slimBarLogoConfig->logo_display_mode == "text"){
            // personalizacao do logo em texto
            $slimBarLogoParams->logoTextStyle = "";
            $slimBarLogoParams->logoTextStyle .= NoBossUtilFonts::importNobossfontlist($logoCustomization->text_logo_font);
            $slimBarLogoParams->logoTextStyle .= "text-transform: {$logoCustomization->text_logo_transform};";
            // pega a cor definida no modulo ou a cor primaria do template
            $logoCustomization->text_logo_color = !empty($logoCustomization->text_logo_color) ? $logoCustomization->text_logo_color : $tmplPrimaryColor;
            $slimBarLogoParams->logoTextStyle .= "color: {$logoCustomization->text_logo_color};";
            // pega a cor definida no modulo ou a cor secundaria do template
            $logoCustomization->text_logo_color_hover = !empty($logoCustomization->text_logo_color_hover) ? $logoCustomization->text_logo_color_hover : $tmplSecondaryColor;
            $slimBarLogoParams->logoTextStyleHover = "color: {$logoCustomization->text_logo_color_hover} !important;";
            $logoTextSize = $logoCustomization->text_logo_size;
            if(!empty($logoTextSize)){
                $logoTextSizeEm = $logoTextSize/16;
                $slimBarLogoParams->logoTextStyle .= "font-size: {$logoTextSize}px; font-size: {$logoTextSizeEm}em;";
            }
            $slimBarLogoParams->logoTextStyleMobile = "";
            if(!empty($logoCustomization->text_logo_size_mobile)){
                $logoTextSizeMobile = $logoCustomization->text_logo_size_mobile;
                $logoTextSizeMobileEm = $logoTextSizeMobile/16;
                $slimBarLogoParams->logoTextStyleMobile .= "font-size: {$logoTextSizeMobile}px; font-size: {$logoTextSizeMobileEm}em !important;";
            }

        }else{
            // Valida se foi cadastrada uma imagem para o logo
            if(!empty($slimBarLogoConfig->image)){
                // Valida se a imagem cadastrada é uma url externa 
                if (filter_var($slimBarLogoConfig->image, FILTER_VALIDATE_URL)) { 
                    $slimBarLogoParams->logoImageUrl = $slimBarLogoConfig->image;
                }else{
                    $slimBarLogoParams->logoImageUrl = JURI::root() . $slimBarLogoConfig->image;
                }
            }

            if(isset($slimBarLogoConfig->show_different_logo_mobile) && $slimBarLogoConfig->show_different_logo_mobile){
                // Valida se foi cadastrada uma imagem para o logo
                if(!empty($slimBarLogoConfig->image_mobile)){
                    // Valida se a imagem cadastrada é uma url externa 
                    if (filter_var($slimBarLogoConfig->image_mobile, FILTER_VALIDATE_URL)) { 
                        $slimBarLogoParams->logoImageUrlMobile = $slimBarLogoConfig->image_mobile;
                    }else{
                        $slimBarLogoParams->logoImageUrlMobile = JURI::root() . $slimBarLogoConfig->image_mobile;
                    }
                }else{
                    $slimBarLogoParams->logoImageUrlMobile = $logoImageUrl;
                }
            }

            // Valida se foi cadastrada uma imagem para o logo apos scroll
            if(isset($slimBarLogoConfig->display_different_image_scroll) && $slimBarLogoConfig->display_different_image_scroll && !empty($slimBarLogoConfig->image_scroll)){
                // Valida se a imagem cadastrada é uma url externa 
                if (filter_var($slimBarLogoConfig->image_scroll, FILTER_VALIDATE_URL)) { 
                    $slimBarLogoParams->logoImageScrollUrl = $slimBarLogoConfig->image_scroll;
                }else{
                    $slimBarLogoParams->logoImageScrollUrl = JURI::root() . $slimBarLogoConfig->image_scroll;
                }
            }else{
                $slimBarLogoParams->logoImageScrollUrl = $logoImageUrl;
            }

            if(isset($slimBarLogoConfig->show_different_logo_mobile) && $slimBarLogoConfig->show_different_logo_mobile){
                // Valida se foi cadastrada uma imagem para o logo apos scroll
                if(isset($slimBarLogoConfig->display_different_image_scroll) && $slimBarLogoConfig->display_different_image_scroll && !empty($slimBarLogoConfig->image_mobile_scroll)){
                    // Valida se a imagem cadastrada é uma url externa 
                    if (filter_var($slimBarLogoConfig->image_mobile_scroll, FILTER_VALIDATE_URL)) { 
                        $slimBarLogoParams->$logoImageScrollUrlMobile = $slimBarLogoConfig->image_mobile_scroll;
                    }else{
                        $slimBarLogoParams->logoImageScrollUrlMobile = JURI::root() . $slimBarLogoConfig->image_mobile_scroll;
                    }
                }else{
                    $slimBarLogoParams->logoImageScrollUrlMobile = $logoImageUrlMobile;
                }
            }

            // valor pro atributo alt da imagem
            $slimBarLogoParams->logoImageAlt = $slimBarLogoConfig->image_alt;


            // verifica se o tamanho foi definido manualmente
            if($logoCustomization->image_manual_size){
                $slimBarLogoParams->logoWidth = "width: {$logoCustomization->image_width}px;";
                $slimBarLogoParams->logoWidthMobile = "width: {$logoCustomization->image_width_mobile}px !important;";
            }
        }
        // espacamentos do logo em desktop e mobile
        $slimBarLogoParams->logoSpacing = ' padding: ' . implode(' ', $logoCustomization->logo_space) . '; ';
        $slimBarLogoParams->logoSpacingMobile =  ' padding: ' . implode(' ', $logoCustomization->logo_space_mobile) . ' !important; ';

        // atributo html title para o link
        $slimBarLogoParams->logoLinkTitleHtml = $slimBarLogoConfig->link_title;
        // guarda o tipo de link (externo ou item de menu)
        $slimBarLogoParams->logoLinkOption = $slimBarLogoConfig->link_option;
        // guarda o target do link
        $slimBarLogoParams->logoLinkTarget = $slimBarLogoConfig->link_target ? "_blank" : "_self";
        // valida se o tipo de link é externo
        if($slimBarLogoParams->logoLinkOption == "external") {
            $slimBarLogoParams->link = $slimBarLogoConfig->link_external;
            // valida se o tipo de link é interno
        } else if($slimBarLogoParams->logoLinkOption == "internal") {
            $slimBarLogoParams->menuItem = $slimBarLogoConfig->link_internal;
            // Obtem o path do item de menu inicial
            if ($slimBarLogoParams->menuItem > 0){
                $slimBarLogoParams->link = NoBossUtilUrl::getUrlItemMenu($slimBarLogoConfig->menuItem);
            }
        }

    }
    $slimBarAdditionalContentParams = $params->get("slim_bar_additional_content");
    $slimBarAdditionalContentParams = (array)$slimBarAdditionalContentParams;
    $slimBarAdditionalContentParams = reset($slimBarAdditionalContentParams);
    $slimBarAdditionalContentParams = (object)$slimBarAdditionalContentParams;

    $slimBarShowAdditionalContent = $slimBarAdditionalContentParams->show_additional_content;
    $slimBarShowAdditionalContentOnMobile = $slimBarAdditionalContentParams->show_on_mobile;
    $slimBarAdditionalContent = $slimBarAdditionalContentParams->slim_bar_additional_content;
    
    $slimBarContactInfoParams = $params->get("slim_bar_contact_info");
    $slimBarContactInfoParams = (array)$slimBarContactInfoParams;
    $slimBarContactInfoParams = reset($slimBarContactInfoParams);
    $slimBarContactInfoParams = (object)$slimBarContactInfoParams;

    $slimBarShowContactInfo = $slimBarContactInfoParams->show_contact_info;
    $slimBarShowContactInfoOnMobile = $slimBarContactInfoParams->show_on_mobile;
    if($slimBarContactInfoParams->show_contact_info){
        $slimBarContactInfoCustomization = $slimBarContactInfoParams->contact_info_customization;
        $slimBarContactInfoCustomization = json_decode($slimBarContactInfoCustomization);

        $slimBarContactInfoStyle = "";
        $slimBarContactInfoStyle .= NoBossUtilFonts::importNobossfontlist($slimBarContactInfoCustomization->font);
        $fontSize = $slimBarContactInfoCustomization->font_size;
        if(!empty($fontSize)){
            $fontSizeEm = $fontSize/16;
            $slimBarContactInfoStyle .= "font-size: {$fontSize}px; font-size: {$fontSizeEm}em;";
        }
        $slimBarContactInfoStyle .= ' color: '.$slimBarContactInfoCustomization->font_color.'; ';
        
        if(isset($slimBarContactInfoCustomization->show_on_mobile) && $slimBarContactInfoCustomization->show_on_mobile){
            $slimBarContactInfoStyleMobile = "";
            $fontSizeMobile = $slimBarContactInfoCustomization->font_size_mobile;
            if(!empty($fontSizeMobile)){
                $fontSizeMobileEm = $fontSizeMobile/16;
                $slimBarContactInfoStyleMobile .= "font-size: {$fontSizeMobile}px; font-size: {$fontSizeMobileEm}em;";
            }
        }
        
        $showIcons = $slimBarContactInfoCustomization->show_icons;
        
        $slimBarContactInfoIconsColor = "";
        if($showIcons){
            $slimBarContactInfoIconsColor .= ' color: '.$slimBarContactInfoCustomization->icons_color. '; ';
        }


        $phone = $slimBarContactInfoParams->phone;
        $email = $slimBarContactInfoParams->email;
    }

    $slimBarAdditionalContentParams = $params->get("slim_bar_additional_content");
}

// TODO: FIM - BARRA SLIM


// TODO: INICIO - BARRA PRINCIPAL E MOBILE

// name da modal de personalizacao do topo
$mainBarModalXml = "items_customization";
// objeto com os parametros definidos na modal de personalizacao do topo
$mainBarModal = json_decode($params->get($mainBarModalXml));

// abaixo serao armazenados os valores definidos na modal do topo

// estilo da galeria de video em resolucoes nao mobile
$mainBarStyle = "";
// estilo da galeria de video em resolucoes mobile
$mainBarStyleMobile = "";


// armazena o estilo do espaçamento interno na variável que é colocada no elemento mais externo
$mainBarStyle .= ' padding: ' . implode(' ', $mainBarModal->items_inner_space) . '; ';
// armazena o estilo do espaçamento interno para o mobile na variável que é colocada no elemento mais externo
$mainBarStyleMobile .= !empty($mobileModal->mobile_items_inner_space) ? 'padding: ' . implode(' ', $mobileModal->mobile_items_inner_space) . ' !important; ' : '';
// armazena o estilo do espaçamento externo na variável que é colocada no elemento mais externo
$mainBarStyle .= ' margin: ' . implode(' ', $mainBarModal->items_outer_space) . '; ';
// armazena o estilo do espaçamento externo na variável que é colocada no elemento mais externo
$mainBarStyleMobile .= !empty($mobileModal->mobile_items_outer_space) ? 'margin: ' . implode(' ', $mobileModal->mobile_items_outer_space) . ' !important; ' : '';

if(empty($mobileModal->mobile_slim_inner_space)){
    $mobileSlimStyle = "padding: 0 0 15px 0";
}
else{
    $mobileSlimStyle = "padding: {$mobileModal->mobile_slim_inner_space[0]} 0 {$mobileModal->mobile_slim_inner_space[1]} 0";
}

// verifica se a largura do conteudo ta sendo definida manualmente
// 1: é manual, então exibe container
// 0: é full width
if($mainBarModal->content_display_mode){
    // largura do conteudo
    $itemColumns = !empty($mainBarModal->content_columns) ? "nb-lg-{$mainBarModal->content_columns} nb-md-{$mainBarModal->content_columns} nb-sm-{$mainBarModal->content_columns} nb-xs-12" : "";
}
// pega a cor definida no modulo ou a cor primaria do template
$mainBarModal->background_color = !empty($mainBarModal->background_color) ? $mainBarModal->background_color : 'rgb(255, 255, 255)';
$mainBarStyle .= !empty($mainBarModal->background_color) ? "background-color: {$mainBarModal->background_color};" : "";

// guarda os itens que serao exibidos em cada posicao
$mainBarPos1 = $mainBarModal->position_1;
$mainBarPos2 = $mainBarModal->position_2;
$mainBarPos3 = $mainBarModal->position_3;
// alinhamento do item do centro
$mainBarPos2Alignment = $mainBarModal->position_2_alignment;

// atributo position
if(!empty($mainBarModal->header_position)){
    if($mainBarModal->header_position == "sticky"){
        $mainBarStyle .= "right: 0; left: 0; ";
    }else{
        $mainBarStyle .= "position: {$mainBarModal->header_position}; ";
    }
}

// pega a cor definida no modulo ou a cor primaria do template
$mobileModal->mobile_background_color = !empty($mobileModal->mobile_background_color) ? $mobileModal->mobile_background_color : 'rgb(255, 255, 255)';
$mainBarStyleMobile .= !empty($mobileModal->mobile_background_color) ? "background-color: {$mobileModal->mobile_background_color};" : "";

// guarda os itens que serao exibidos em cada posicao
$headerMobilePos1 = (!empty($mobileModal->mobile_position_1)) ? $mobileModal->mobile_position_1 : '';
$headerMobilePos2 = (!empty($mobileModal->mobile_position_2)) ? $mobileModal->mobile_position_2 : '';
$headerMobilePos3 = (!empty($mobileModal->mobile_position_3)) ? $mobileModal->mobile_position_3 : '';

// alinhamento do item do centro
$headerMobilePos2Alignment = (!empty($mobileModal->mobile_position_2_alignment)) ? $mobileModal->mobile_position_2_alignment : '';

// pega os itens cadastrados no subform
$menuItems = $params->get('position'); 

// Menu da barra principal setado para ser exibida no mobile
$menuMobileMain = $params->get('main_bar_display_mobile', 1);

// TODO: INICIO - MENU BARRA PRINCIPAL E MENU MOBILE

if(!empty($menuItems)){
    // Obtem modulo de menu para exibir
    $mainBarModuleMenu = JModuleHelper::getModules($menuItems);
}

if (!empty($mainBarModuleMenu)){
    // renderiza o módulo para devolver o html 
    $mainBarModuloMenuHtml = JModuleHelper::renderModule( $mainBarModuleMenu[0] );

    // TODO: INICIO - MENU DESKTOP
    $mainBarMenuParams = new \stdClass;

    $mainBarMenuParams->sideMenuParams = new \stdClass;

    // Menu burguer habilitado
    if($mainBarModal->show_menu_burguer){
        if($mainBarPos1 === 'menu' || $mainBarPos2 === 'menu'){
            $mainBarWrapperClass = 'left';
            $mainBarHasSideMenu = true;
        }else if($mainBarPos3 === 'menu'){
            $mainBarWrapperClass = 'right';
            $mainBarHasSideMenu = true;
        }else{
            $mainBarHasSideMenu = false;
        }

        $mainBarMenuParams->sideMenuParams->style = "";
        $mainBarMenuParams->sideMenuParams->style .= ' width: '.$mainBarModal->menu_burger_width.'%; ';
        $mainBarMenuParams->sideMenuParams->style .= ' background-color: '.$mainBarModal->menu_burger_background_color.'; ';

        $mainBarMenuParams->sideMenuParams->headerStyle = "";
        $mainBarMenuParams->sideMenuParams->headerStyle .= ' background-color: '.$mainBarModal->menu_burger_header_background_color.'; ';
        $mainBarMenuParams->sideMenuParams->headerStyle .= ' height: '.$mainBarModal->menu_burger_header_height.'%; ';
        $mainBarMenuParams->sideMenuParams->closeButtonColor = ' color: '.$mainBarModal->menu_burger_close_icon_color.'; ';

        $mainBarMenuParams->sideMenuParams->itemsBorder = "";
        if($mainBarModal->menu_burger_items_show_border){
            $mainBarMenuParams->sideMenuParams->itemsBorder .= 'border-style: solid; border-color: '.$mainBarModal->menu_burger_items_border_color .'; border-width: '.implode(" ",$mainBarModal->menu_burger_items_border) . '; ';
        }

        // Estilo do ícone de menu 
        $mainBarMenuParams->sideMenuParams->desktopMenuIconStyle = "";
    
        // pega a cor definida no modulo ou a cor primaria do template
        $mainBarModal->desktop_menu_icon_color = !empty($mainBarModal->desktop_menu_icon_color) ? $mainBarModal->desktop_menu_icon_color : 'rgb(255, 255, 255)';
        $mainBarMenuParams->sideMenuParams->desktopMenuIconStyle .= "color: {$mainBarModal->desktop_menu_icon_color} !important;";
        $desktopMenuIconSize = $mainBarModal->desktop_menu_icon_size;
        if(!empty($desktopMenuIconSize)){
            $desktopMenuIconSizeEm = $desktopMenuIconSize/16;
            $mainBarMenuParams->sideMenuParams->desktopMenuIconStyle .= "font-size: {$desktopMenuIconSize}px; font-size: {$desktopMenuIconSizeEm}em !important;";
        }
        $mainBarMenuParams->sideMenuParams->desktopMenuIconStyle .= ' padding: ' . implode(' ', $mainBarModal->desktop_icons_space) . '; ';   

    }

    // Prepara os dados do menu normal para exibicao
    $menuReturn = ModNobossheaderHelper::prepareActionsMenu($mainBarMenuParams, $mainBarModal, 'mainBar');
    $mainBarMenuParams = $menuReturn->menuParams;
    $mainBarModal = $menuReturn->menuCustomization;

    // TODO: FIM - MENU DESKTOP


    // TODO: INICIO - MENU MOBILE (estilo para menus das barras slim, principal e secundaria)
    // estilo de texto do menu no mobile
    $mainBarMenuParams->menuTextStyleMobile = "";
    $mainBarMenuParams->menuStyleMobile = "";
    $mainBarMenuParams->menuTextStyleMobile .= (!empty($mobileModal->menu_mobile_text_transform)) ? "text-transform: {$mobileModal->menu_mobile_text_transform};" : "";
    
    // pega a cor definida no modulo ou a cor primaria do template
    $mobileModal->menu_mobile_text_color = !empty($mobileModal->menu_mobile_text_color) ? $mobileModal->menu_mobile_text_color : $tmplPrimaryColor;  
    $mainBarMenuParams->menuTextStyleMobile .= (!empty($mobileModal->menu_mobile_text_color)) ? "color: {$mobileModal->menu_mobile_text_color};" : "";
    $mainBarMenuParams->menuStyleMobile .= (!empty($mobileModal->menu_mobile_background_color)) ? "background-color: {$mobileModal->menu_mobile_background_color};" : "";

    if(!empty($mobileModal->menu_space)){
        $mainBarMenuParams->menuStyleMobile .= ' padding: ' . implode(' ', $mobileModal->menu_space) . '; ';
    }
    
    $menuTextSizeMobile = (!empty($mobileModal->menu_mobile_text_size)) ? $mobileModal->menu_mobile_text_size : "";

    if(!empty($menuTextSizeMobile)){
        $menuTextSizeMobileEm = $menuTextSizeMobile/16;
        $mainBarMenuParams->menuTextStyleMobile .= "font-size: {$menuTextSizeMobile}px; font-size: {$menuTextSizeMobileEm}em;";
    }
    $mainBarMenuParams->menuMobileItemsStyle = "";

    // verifica se tem borda entre os itens
    if(!empty($mobileModal->menu_mobile_show_border)){
        // pega a cor definida no modulo ou a cor secundaria do template
        $mobileModal->menu_mobile_border_color = !empty($mobileModal->menu_mobile_border_color) ? $mobileModal->menu_mobile_border_color : $tmplSecondaryColor;
        $mainBarMenuParams->menuMobileItemsStyle .= "border-style: solid; border-width: " . implode(" ", $mobileModal->menu_mobile_border) . "; border-color: {$mobileModal->menu_mobile_border_color};";
    }
    
    $mainBarMenuParams->menuMobileTextStyleHover = "";
    // pega a cor definida no modulo ou a cor secundaria do template
    $mobileModal->menu_mobile_active_text_color = !empty($mobileModal->menu_mobile_active_text_color) ? $mobileModal->menu_mobile_active_text_color : $tmplSecondaryColor;
    // personalizacao do hover / item ativo
    $mainBarMenuParams->menuMobileTextStyleHover = !empty($mobileModal->menu_mobile_active_text_color) ? " color: {$mobileModal->menu_mobile_active_text_color} !important;" : "";
    
    // verifica se tem cor de fundo no hover
    if(!empty($mobileModal->menu_mobile_active_show_background)){
        // pega a cor definida no modulo ou a cor secundaria do template
        $mobileModal->menu_mobile_active_background_color = !empty($mobileModal->menu_mobile_active_background_color) ? $mobileModal->menu_mobile_active_background_color : $tmplSecondaryColor;
        $mainBarMenuParams->menuMobileTextStyleHover .= !empty($mobileModal->menu_mobile_active_background_color) ? "background-color: {$mobileModal->menu_mobile_active_background_color};" : "background-color: transparent;";
    }


    // Espacamento interno <li> do menu
    $mainBarMenuParams->menuMobileOuterSpace = (!empty($mobileModal->menu_mobile_items_outer_space)) ? ' padding: ' . implode(' ', $mobileModal->menu_mobile_items_outer_space) . '; ' : '';    

    // Espacamento interno link do menu
    $mainBarMenuParams->menuMobileInnerSpace = (!empty($mobileModal->menu_mobile_items_inner_space)) ? ' padding: ' . implode(' ', $mobileModal->menu_mobile_items_inner_space) . '; ' : '';


    // Espacamento dos links / botoes de acao dentro do menu
    $mainBarMenuParams->actionsButtonsMenuStyleMobile = !empty($mobileModal->actions_links_outer_space_mobile) ? ' margin: ' . implode(' ', $mobileModal->actions_links_outer_space_mobile) . '; ' : ' margin: 20px 0 0 0;';

    // Alinhamento dos links / botoes de acao dentro do menu
    if(empty($mobileModal->actions_links_position_mobile)){
        $mobileModal->actions_links_position_mobile = 'center';
    }
    $mainBarMenuParams->actionsButtonsMenuStyleMobile .= !empty($mobileModal->actions_links_position_mobile) ? " display: block; text-align: {$mobileModal->actions_links_position_mobile}" : "";

    // Estilo do ícone de menu 
    $mainBarMenuParams->menuIconStyle = "";
    
    // pega a cor definida no modulo ou a cor primaria do template
    $mobileModal->menu_icon_color = !empty($mobileModal->menu_icon_color) ? $mobileModal->menu_icon_color : $tmplPrimaryColor;
    $mainBarMenuParams->menuIconStyle .= "color: {$mobileModal->menu_icon_color};";
    
    $menuIconSize = (!empty($mobileModal->menu_icon_size)) ? $mobileModal->menu_icon_size : '';

    if(!empty($menuIconSize)){
        $menuIconSizeEm = $menuIconSize/16;
        $mainBarMenuParams->menuIconStyle .= "font-size: {$menuIconSize}px; font-size: {$menuIconSizeEm}em !important;";
    }

    // estilo do submenu no mobile 
    // guarda se o submenu deve vir exibido por padrao
    // $showSubmenu = $mainBarModal->show_submenu;

    $mainBarMenuParams->submenuStyleMobile = "";
    $mainBarMenuParams->submenuStyleMobile .= (!empty($mobileModal->submenu_mobile_background_color)) ? "background-color: {$mobileModal->submenu_mobile_background_color} !important; " : '';
    $mainBarMenuParams->submenuMobileTextStyleHover = "";
    // estilo de texto do submenu no mobile
    $mainBarMenuParams->submenuTextStyleMobile = "";
    $mainBarMenuParams->submenuTextStyleMobile .= (!empty($mobileModal->submenu_mobile_text_transform)) ? "text-transform: {$mobileModal->submenu_mobile_text_transform};" : "";
    
    // pega a cor definida no modulo ou a cor primaria do template
    $mobileModal->submenu_mobile_text_color = !empty($mobileModal->submenu_mobile_text_color) ? $mobileModal->submenu_mobile_text_color : $tmplPrimaryColor;
    $mainBarMenuParams->submenuTextStyleMobile .= (!empty($mobileModal->submenu_mobile_text_color)) ? "color: {$mobileModal->submenu_mobile_text_color} !important; " : "";
    
    $mainBarMenuParams->submenuTextStyleMobile .= (!empty($mobileModal->submenu_mobile_text_alignment)) ? "text-align: {$mobileModal->submenu_mobile_text_alignment} !important; " : "";

    $mainBarMenuParams->submenuTextSizeMobile = (!empty($mobileModal->submenu_mobile_text_size)) ? $mobileModal->submenu_mobile_text_size : '';

    if(!empty($mainBarMenuParams->submenuTextSizeMobile)){
        $mainBarMenuParams->submenuTextSizeMobileEm = $mainBarMenuParams->submenuTextSizeMobile/16;
        $mainBarMenuParams->submenuTextStyleMobile .= "font-size: {$mainBarMenuParams->submenuTextSizeMobile}px; font-size: {$mainBarMenuParams->submenuTextSizeMobileEm}rem !important;";
    }

    $mainBarMenuParams->submenuMobileItemsStyle = "";
    
    // verifica se tem borda entre os itens
    if(!empty($mobileModal->submenu_mobile_show_border)){
        // pega a cor definida no modulo ou a cor secundaria do template
        $mobileModal->submenu_mobile_border_color = !empty($mobileModal->submenu_mobile_border_color) ? $mobileModal->submenu_mobile_border_color : $tmplSecondaryColor;
        $mainBarMenuParams->submenuMobileItemsStyle .= "border-style: solid; border-width: " . implode(" ", $mobileModal->submenu_mobile_border) . "; border-color: {$mobileModal->submenu_mobile_border_color};";
    }
    
    $mainBarMenuParams->submenuMobileTextStyleHover = "";
    // pega a cor definida no modulo ou a cor secundaria do template
    $mobileModal->submenu_mobile_active_text_color = !empty($mobileModal->submenu_mobile_active_text_color) ? $mobileModal->submenu_mobile_active_text_color : $tmplSecondaryColor;
    // personalizacao do hover / item ativo
    $mainBarMenuParams->submenuMobileTextStyleHover = !empty($mobileModal->submenu_mobile_active_text_color) ? " color: {$mobileModal->submenu_mobile_active_text_color} !important;" : "";
    
    // verifica se tem cor de fundo no hover
    if(!empty($mobileModal->submenu_mobile_active_show_background)){
        // pega a cor definida no modulo ou a cor secundaria do template
        $mobileModal->submenu_mobile_active_background_color = !empty($mobileModal->submenu_mobile_active_background_color) ? $mobileModal->submenu_mobile_active_background_color : $tmplSecondaryColor;
        $mainBarMenuParams->submenuMobileTextStyleHover .= !empty($mobileModal->submenu_mobile_active_background_color) ? "background-color: {$mobileModal->submenu_mobile_active_background_color};" : "background-color: transparent;";
    }

    // Espacamento interno <li> do submenu
    $mainBarMenuParams->submenuMobileOuterSpace = (!empty($mobileModal->submenu_mobile_items_outer_space)) ? ' padding: ' . implode(' ', $mobileModal->submenu_mobile_items_outer_space) . '; ' : '';    

    // Espacamento interno link do submenu
    $mainBarMenuParams->submenuMobileInnerSpace = (!empty($mobileModal->submenu_mobile_items_inner_space)) ? ' padding: ' . implode(' ', $mobileModal->submenu_mobile_items_inner_space) . '; ' : '';
    

    // TODO: FIM - MENU MOBILE

}
// TODO: FIM - MENU BARRA PRINCIPAL E MENU MOBILE

// TODO: INICIO - LOGO
// pega as configuracoes de logo
$mainBarLogoConfig = $params->get("logo");
$mainBarLogoConfig = (array)$mainBarLogoConfig;
$mainBarLogoConfig = reset($mainBarLogoConfig);
$mainBarLogoConfig = (object)$mainBarLogoConfig;

$mainBarLogoParams = new \stdClass;
$mainBarLogoParams->logoConfig = $mainBarLogoConfig;

// verifica se o logo deve ser exibido
if($mainBarLogoConfig->show_logo){
    // objeto da modal de personazalicao do logo
    $logoCustomization = json_decode($mainBarLogoConfig->logo_customization);
    
    // verifica se o logo eh em forma de texto
    if($mainBarLogoConfig->logo_display_mode == "text"){
        // personalizacao do logo em texto
        $mainBarLogoParams->logoTextStyle = "";
        $mainBarLogoParams->logoTextStyle .= NoBossUtilFonts::importNobossfontlist($logoCustomization->text_logo_font);
        $mainBarLogoParams->logoTextStyle .= "text-transform: {$logoCustomization->text_logo_transform};";
        // pega a cor definida no modulo ou a cor primaria do template
        $logoCustomization->text_logo_color = !empty($logoCustomization->text_logo_color) ? $logoCustomization->text_logo_color : $tmplPrimaryColor;
        $mainBarLogoParams->logoTextStyle .= "color: {$logoCustomization->text_logo_color};";
        // pega a cor definida no modulo ou a cor secundaria do template
        $logoCustomization->text_logo_color_hover = !empty($logoCustomization->text_logo_color_hover) ? $logoCustomization->text_logo_color_hover : $tmplSecondaryColor;
        $mainBarLogoParams->logoTextStyleHover = "color: {$logoCustomization->text_logo_color_hover} !important;";
        $logoTextSize = $logoCustomization->text_logo_size;
        if(!empty($logoTextSize)){
            $logoTextSizeEm = $logoTextSize/16;
            $mainBarLogoParams->logoTextStyle .= "font-size: {$logoTextSize}px; font-size: {$logoTextSizeEm}em;";
        }
        $mainBarLogoParams->logoTextStyleMobile = "";
        if(!empty($logoCustomization->text_logo_size_mobile)){
            $logoTextSizeMobile = $logoCustomization->text_logo_size_mobile;
            $logoTextSizeMobileEm = $logoTextSizeMobile/16;
            $mainBarLogoParams->logoTextStyleMobile .= "font-size: {$logoTextSizeMobile}px; font-size: {$logoTextSizeMobileEm}em !important;";
        }

    }else{
        // Valida se foi cadastrada uma imagem para o logo
        if(!empty($mainBarLogoConfig->image)){
            // Valida se a imagem cadastrada é uma url externa 
            if (filter_var($mainBarLogoConfig->image, FILTER_VALIDATE_URL)) { 
                $mainBarLogoParams->logoImageUrl = $mainBarLogoConfig->image;
            }else{
                $mainBarLogoParams->logoImageUrl = JURI::root() . $mainBarLogoConfig->image;
            }
        }

        if(isset($mainBarLogoConfig->show_different_logo_mobile) && $mainBarLogoConfig->show_different_logo_mobile){
            // Valida se foi cadastrada uma imagem para o logo
            if(!empty($mainBarLogoConfig->image_mobile)){
                // Valida se a imagem cadastrada é uma url externa 
                if (filter_var($mainBarLogoConfig->image_mobile, FILTER_VALIDATE_URL)) { 
                    $mainBarLogoParams->logoImageUrlMobile = $mainBarLogoConfig->image_mobile;
                }else{
                    $mainBarLogoParams->logoImageUrlMobile = JURI::root() . $mainBarLogoConfig->image_mobile;
                }
            }else{
                if(isset($logoImageUrl)){
                    $mainBarLogoParams->logoImageUrlMobile = $logoImageUrl;
                }
            }
        }

        // Valida se foi cadastrada uma imagem para o logo apos scroll
        if(isset($mainBarLogoConfig->display_different_image_scroll) && $mainBarLogoConfig->display_different_image_scroll && !empty($mainBarLogoConfig->image_scroll)){
            // Valida se a imagem cadastrada é uma url externa 
            if (filter_var($mainBarLogoConfig->image_scroll, FILTER_VALIDATE_URL)) { 
                $mainBarLogoParams->logoImageScrollUrl = $mainBarLogoConfig->image_scroll;
            }else{
                $mainBarLogoParams->logoImageScrollUrl = JURI::root() . $mainBarLogoConfig->image_scroll;
            }
        }else{
            if(isset($logoImageUrl)){
                $mainBarLogoParams->logoImageScrollUrl = $logoImageUrl;
            }
        }

        if(isset($mainBarLogoConfig->show_different_logo_mobile) && $mainBarLogoConfig->show_different_logo_mobile){
            // Valida se foi cadastrada uma imagem para o logo apos scroll
            if(isset($mainBarLogoConfig->display_different_image_scroll) && $mainBarLogoConfig->display_different_image_scroll && !empty($mainBarLogoConfig->image_mobile_scroll)){
                // Valida se a imagem cadastrada é uma url externa 
                if (filter_var($mainBarLogoConfig->image_mobile_scroll, FILTER_VALIDATE_URL)) { 
                    $mainBarLogoParams->$logoImageScrollUrlMobile = $mainBarLogoConfig->image_mobile_scroll;
                }else{
                    $mainBarLogoParams->logoImageScrollUrlMobile = JURI::root() . $mainBarLogoConfig->image_mobile_scroll;
                }
            }else{
                if(isset($logoImageUrlMobile)){
                    $mainBarLogoParams->logoImageScrollUrlMobile = $logoImageUrlMobile;
                }
            }
        }

        // valor pro atributo alt da imagem
        $mainBarLogoParams->logoImageAlt = $mainBarLogoConfig->image_alt;


        // verifica se o tamanho foi definido manualmente
        if($logoCustomization->image_manual_size){
            $mainBarLogoParams->logoWidth = "width: {$logoCustomization->image_width}px;";
            $mainBarLogoParams->logoWidthMobile = "width: {$logoCustomization->image_width_mobile}px !important;";
        }
    }
    // espacamentos do logo em desktop e mobile
    $mainBarLogoParams->logoSpacing = ' padding: ' . implode(' ', $logoCustomization->logo_space) . '; ';
    $mainBarLogoParams->logoSpacingMobile =  ' padding: ' . implode(' ', $logoCustomization->logo_space_mobile) . ' !important; ';

    // atributo html title para o link
    $mainBarLogoParams->logoLinkTitleHtml = $mainBarLogoConfig->link_title;
    // guarda o tipo de link (externo ou item de menu)
    $mainBarLogoParams->logoLinkOption = $mainBarLogoConfig->link_option;
    // guarda o target do link
    $mainBarLogoParams->logoLinkTarget = $mainBarLogoConfig->link_target ? "_blank" : "_self";
    // valida se o tipo de link é externo
    if($mainBarLogoParams->logoLinkOption == "external") {
        $mainBarLogoParams->link = $mainBarLogoConfig->link_external;
        // valida se o tipo de link é interno
    } else if($mainBarLogoParams->logoLinkOption == "internal") {
        $mainBarLogoParams->menuItem = $mainBarLogoConfig->link_internal;
        // Obtem o path do item de menu inicial
        if ($mainBarLogoParams->menuItem > 0){
            $mainBarLogoParams->link = NoBossUtilUrl::getUrlItemMenu($mainBarLogoParams->menuItem);
        }
    }
}

// TODO: FIM - LOGO

// inicia a flag de exibir cada item adicional como false
$mainBarShowActionLinks = $params->get('show_action_links');

// NBTODO: NÃO EXCLUIR CÓDIGO COMENTADO ABAIXO, SERÁ IMPLEMENTADO NO FUTURO
// ------------------- CAN'T TOUCH THIS --------------------- //
    // $showSocialMedia = false;
    // $showAccessibility = false;
    // $showModulePosition = false;
// ------------------------ ENDING --------------------- // 

$addItems = $params->get('additional_items');

// Botoes / links de acao a exibir
if((isset($mainBarShowActionLinks) && $mainBarShowActionLinks) || (isset($addItems) && in_array('action_links', $addItems))){
    // Pega os itens cadastrados
    $mainBarLinks = $params->get("action_links");
    
    // Prepara os dados dos botoes para exibicao
    $mainBarLinks = ModNobossheaderHelper::prepareActionsButtons($mainBarLinks);
}

// NBTODO: NÃO EXCLUIR CÓDIGO COMENTADO ABAIXO, SERÁ IMPLEMENTADO NO FUTURO
// ------------------- CAN'T TOUCH THIS --------------------- // 

    // verifica se o item adicional de acessibilidade deve ser exibido
    /* if(in_array('accessibility', $addItems)){
        $showAccessibility = true;
        // pega o item cadastrado no subform de acessibilidade
        $accessibilityItem = $params->get("accessibility");
        $accessibilityItem = reset($accessibilityItem);
        // objeto com parametros da modal de personalizacao
        $accessibilityCustomization = json_decode($accessibilityItem->accessibility_customization);
        
        // cria objeto pra guardar os parametros de acessibilidade
        $accessibility = new \stdClass;
        $accessibility->showOnMobile = $accessibilityItem->show_on_mobile;
        $accessibility->enableLink = $accessibilityItem->enable_accessibility_link;
        $accessibility->showInsideMenu = $accessibilityItem->show_inside_menu;
        $accessibility->showItem = $accessibilityItem->show_item;
        // verifica se o link de acessibilidade foi habilitado
        if($accessibility->enableLink){
            // guarda o tipo de link (externo ou item de menu)
            $linkOption = $accessibilityItem->accessibility_link_option;
            // guarda o target do link
            $linkTarget = $accessibilityItem->accessibility_link_target ? "_blank" : "_self";
            // valida se o tipo de link é externo
            if($linkOption == "external") {
                $accessibility->link = $accessibilityItem->accessibility_link_external;
            } else {
                $menuItem = $accessibilityItem->accessibility_link_internal;
                // Obtem o path do item de menu inicial
                if ($menuItem > 0){
                    $accessibility->link = NoBossUtilUrl::getUrlItemMenu($menuItem);
                }
            }
            // tag title pro link
            $accessibility->linkTitle = $accessibilityItem->accessibility_link_title;
        }
        // guarda se o alto contrase foi habilitado
        $accessibility->enableHighContrast = $accessibilityItem->enable_high_contrast;
        // guarda se a troca de tamanho da fonte foi habilitada
        $accessibility->enableFontChanging = $accessibilityItem->enable_font_changing;
        // estilo da modal de personalizacao
        // exit(var_dump($accessibilityCustomization));

        $accessibility->textStyle .= NoBossUtilFonts::importNobossfontlist($accessibilityItem->accessibility_text);
        $accessibility->textStyle .= " text-transform: " . $accessibilityItem->accessibility_text_transform . ";";
        $accessibility->textStyle .= " color: " . $accessibilityItem->accessibility_text_color . ";";
        $inputSize = $accessibilityItem->accessibility_text_size;
        if(!empty($inputSize)){
            $inputSizeEm = $inputSize/16;
            $accessibility->textStyle .= " font-size: {$inputSize}px; font-size: {$inputSizeEm}em;";
        }
        $accessibility->textStyleHover .= " color: " . $accessibilityItem->accessibility_hover_text_color . " !important;";

    } */ 
// ------------------------ ENDING --------------------- // 

// TODO: FIM - BARRA PRINCIPAL E MOBILE


// TODO: INICIO - BARRA SECUNDARIA

// pega os itens cadastrados no subform
$menuItems = $params->get('secondary_bar_position'); 

// Menu da barra secundaria setado para ser exibida no mobile
$menuMobileSecondary = $params->get('secondary_bar_display_mobile', 0);

if(!empty($menuItems)){
    // Obtem modulo de menu para exibir
    $secondaryBarModuleMenu = JModuleHelper::getModules($menuItems);
}

$showSecondaryBar = $params->get('show_secondary_bar');

if(!empty($secondaryBarModuleMenu) && $showSecondaryBar){

    $secondaryBarMenuPosition = $params->get('secondary_bar_position');

    // name da modal de personalizacao do topo
    $secondaryBarModalXml = "secondary_bar_customization";
    // objeto com os parametros definidos na modal de personalizacao do topo
    $secondaryBarModal = json_decode($params->get($secondaryBarModalXml));

    // estilo da galeria de video em resolucoes nao mobile
    $secondaryBarStyle = "";
    // armazena o estilo do espaçamento interno na variável que é colocada no elemento mais externo
    $secondaryBarStyle .= ' padding: ' . implode(' ', $secondaryBarModal->items_inner_space) . '; ';
    // armazena o estilo do espaçamento externo na variável que é colocada no elemento mais externo
    $secondaryBarStyle .= ' margin: ' . implode(' ', $secondaryBarModal->items_outer_space) . '; ';

    // verifica se a largura do conteudo ta sendo definida manualmente
    // 1: é manual, então exibe container
    // 0: é full width
    if($secondaryBarModal->content_display_mode){
        // largura do conteudo
        $itemColumns = !empty($secondaryBarModal->content_columns) ? "nb-lg-{$secondaryBarModal->content_columns} nb-md-{$secondaryBarModal->content_columns} nb-sm-{$secondaryBarModal->content_columns} nb-xs-12" : "";
    }
    // pega a cor definida no modulo ou a cor primaria do template
    $secondaryBarModal->background_color = !empty($secondaryBarModal->background_color) ? $secondaryBarModal->background_color : $tmplPrimaryColor;
    $secondaryBarStyle .= !empty($secondaryBarModal->background_color) ? "background-color: {$secondaryBarModal->background_color};" : "";

    if(isset($secondaryBarModal->position_alignment)){
        $secondaryBarPosition = $secondaryBarModal->position_alignment;
        if($secondaryBarPosition === 'center'){
            $secondaryBarPositionStyle =  'margin: 0 auto; ';
        }else if($secondaryBarPosition === 'right'){
            $secondaryBarPositionStyle = ' margin-right: auto; ';
        }else{
            $secondaryBarPositionStyle = ' margin-left: auto; ';
        }
    }
    
    // renderiza o módulo para devolver o html 
    $secondaryBarModuloMenuHtml = JModuleHelper::renderModule( $secondaryBarModuleMenu[0] );
    // -------------------------------- MENU DESKTOP ----------------------------------------- //
        $secondaryBarMenuParams = new \stdClass;

        // Prepara os dados do menu para exibicao
        $menuReturn = ModNobossheaderHelper::prepareActionsMenu($secondaryBarMenuParams, $secondaryBarModal, 'secondaryBar');
        $secondaryBarMenuParams = $menuReturn->menuParams;
        $secondaryBarModal = $menuReturn->menuCustomization;
}
// TODO: FIM - BARRA SECUNDARIA


// TODO: INICIO - BUSCA
$showSearch = $params->get('display_search');
$searchParams = $params->get("search");
$searchParams = (array)$searchParams;
$searchParams = reset($searchParams);
$searchParams = (object)$searchParams;

$searchCustomization = json_decode($searchParams->search_customization);
$searchConfig = new \stdClass;
$searchConfig->showOnMobile = false;

if((isset($showSearch) && $showSearch) || (isset($addItems) && in_array('search', $addItems))){
    // cria um objeto pra guardar toda a configuracao do form de busca
    $searchConfig->showOnMobile = $searchParams->show_on_mobile;
    if(isset($searchParams->display_location)){
        $searchConfig->displayLocation = $searchParams->display_location;
    }else{
        $searchConfig->displayLocation = 'main';
    }
    $searchConfig->inputName = $searchParams->input_name;
    $searchConfig->placeholder = rtrim($searchParams->input_placeholder);
    $searchConfig->submissionMethod = $searchParams->submission_method;
    // inicia url de acao do form vazio
    $searchConfig->actionUrl = "";
    // valida se a url do form é externa
    if($searchParams->url_option == "external") {
        $searchConfig->actionUrl = $searchParams->link_external;
    } else {
        $menuItem = $searchParams->link_internal;
        // Obtem o path do item de menu inicial
        if ($menuItem > 0){
            $searchConfig->actionUrl = NoBossUtilUrl::getUrlItemMenu($menuItem);
        }
    }
    // decoda toda a configuracao da modal de personalizacao do form de busca
    $searchCustomization = json_decode($searchParams->search_customization);
    
    // variavel pra guardar a personalizacao do form de busca
    $searchConfig->style = new \stdClass;
    // $searchConfig->style->showInput = $searchCustomization->show_input;
    // estilo do input
    $searchConfig->style->inputStyle = "";
    $searchConfig->style->inputStyle .= NoBossUtilFonts::importNobossfontlist($searchCustomization->inputs_text_font);
    $searchConfig->style->inputStyle .= " text-align: " . $searchCustomization->inputs_text_alignment . "; text-align-last: " . $searchCustomization->inputs_text_alignment . ";";
    $searchConfig->style->inputStyle .= " text-transform: " . $searchCustomization->inputs_text_transform . ";";
    // pega a cor definida no modulo ou a cor primaria do template
    $searchCustomization->inputs_text_color = !empty($searchCustomization->inputs_text_color) ? $searchCustomization->inputs_text_color : $tmplPrimaryColor;
    $searchConfig->style->inputStyle .= " color: " . $searchCustomization->inputs_text_color . ";";
    // pega a cor definida no modulo ou a cor primaria do template
    $searchCustomization->background_color = !empty($searchCustomization->background_color) ? $searchCustomization->background_color : $tmplPrimaryColor;
    $searchConfig->style->inputBackground = " background-color: " . $searchCustomization->background_color . ";";
    $inputSize = $searchCustomization->inputs_text_size;
    if(!empty($inputSize)){
        $inputSizeEm = $inputSize/16;
        $searchConfig->style->inputStyle .= " font-size: {$inputSize}px; font-size: {$inputSizeEm}em;";
    }

    // NBTODO: NÃO EXCLUIR CÓDIGO COMENTADO ABAIXO, SERÁ IMPLEMENTADO NO FUTURO
    // ------------------- CAN'T TOUCH THIS --------------------- //
        /*
        // Variavel que armazenara o estilo da borda do campo
        $searchConfig->style->borderStyle = '';
        // Verifica se deve exibir borda no input
        if($searchCustomization->show_inputs_border){
            // Verifica se deve exibir borda apenas embaixo do campo
            if($searchCustomization->inputs_one_line_border){
                $searchConfig->style->borderStyle .= "border-radius: 0px; border: 0; border-bottom: " . $searchCustomization->border_size . "px solid " . $searchCustomization->border_color . ";";
            }else{
                $searchConfig->style->borderStyle .= "padding: .5em 1em; border: " . $searchCustomization->border_size . "px solid " . $searchCustomization->border_color . ";";
                $searchConfig->style->borderStyle .= " \n border-radius: " . $searchCustomization->border_radius . "px;";
            }
        }else{
            $searchConfig->style->borderStyle = 'border: 0px;';
        } */ 
    // ------------------------ ENDING --------------------- // 

    // variável utilizada para armazenar os estilos dos ícones
    $searchConfig->style->iconStyle = "vertical-align: middle;";
    $searchConfig->style->iconStyleMobile = "";

    $searchConfig->style->hasBorder = $searchCustomization->show_icons_border ? 'has-border' : '';
    // pega a cor definida no modulo ou a cor primaria do template
    $searchCustomization->icons_color = !empty($searchCustomization->icons_color) ? $searchCustomization->icons_color : $tmplPrimaryColor;
    $searchConfig->style->iconStyle .= "color: {$searchCustomization->icons_color}; ";
    // pega a cor definida no modulo ou a cor secundaria do template
    $searchCustomization->icons_background = !empty($searchCustomization->icons_background) ? $searchCustomization->icons_background : $tmplSecondaryColor;
    $searchConfig->style->iconStyle .= $searchCustomization->show_icons_background ? " background-color: {$searchCustomization->icons_background};" : '';
    $searchConfig->style->iconStyle .= $searchCustomization->show_icons_border ? " border: 1px solid {$searchCustomization->icons_border_color};" : '';
    $searchConfig->style->iconStyle .= $searchCustomization->show_icons_border_radius ? " border-radius:  {$searchCustomization->icons_border_radius}px; " : '';
    $iconsSize = $searchCustomization->icons_size;
    // configura o tamanho do icone
    if(!empty($iconsSize)){
        $iconsSizeEm = $iconsSize/16;
        $searchConfig->style->iconSize = "font-size: {$iconsSize}px; font-size: {$iconsSizeEm}em;";
        $searchConfig->style->iconStyle .= $searchConfig->style->iconSize;
    }
    // if(!$searchConfig->style->showInput){
        $searchConfig->style->iconStyle .= ' padding: ' . implode(' ', $searchCustomization->icons_inner_space) . '; ';
        $searchConfig->style->iconStyle .= ' margin: ' . implode(' ', $searchCustomization->icons_outer_space) . '; ';  
    // }
    // configura o tamanho do icone no mobile
    if(!empty($searchCustomization->icons_size_mobile)){
        $iconSizeMobile = $searchCustomization->icons_size_mobile;
        $iconSizeMobileEm = $iconSizeMobile/16;
        $searchConfig->style->iconStyleMobile .= "font-size: {$iconSizeMobile}px; font-size: {$iconSizeMobileEm}em !important;";
    }
    // estilo para ícones no hover 
    $searchConfig->style->iconStyleHover = "";
    if($searchCustomization->enable_icons_hover){
        // pega a cor definida no modulo ou a cor secundaria do template
        $searchCustomization->icons_color_hover = !empty($searchCustomization->icons_color_hover) ? $searchCustomization->icons_color_hover : $tmplSecondaryColor;
        $searchConfig->style->iconStyleHover .= "color: {$searchCustomization->icons_color_hover} !important; ";
        // pega a cor definida no modulo ou a cor primaria do template
        $searchCustomization->icons_background_hover = !empty($searchCustomization->icons_background_hover) ? $searchCustomization->icons_background_hover : $tmplPrimaryColor;
        $searchConfig->style->iconStyleHover .= $searchCustomization->show_icons_background ? "background-color: {$searchCustomization->icons_background_hover} !important; ": '';
        // pega a cor definida no modulo ou a cor primaria do template
        $searchCustomization->icons_border_color_hover = !empty($searchCustomization->icons_border_color_hover) ? $searchCustomization->icons_border_color_hover : $tmplPrimaryColor;
        $searchConfig->style->iconStyleHover .= $searchCustomization->show_icons_border ? "border-color: {$searchCustomization->icons_border_color_hover} !important; " : '';
    }
}
// TODO: INICIO - BUSCA


// TODO: INICIO - IDIOMA
$showLang = $params->get('display_language');
$langParams = $params->get("language");
$langParams = (array)$langParams;
$langParams = reset($langParams);
$langParams = (object)$langParams;

$langCustomization = json_decode($langParams->language_customization);
// objeto para armazenar estilos do desktop 
$langConfigDesk = new \stdClass();
// objeto para armazenar estilos do mobile 
$langConfigMobile = new \stdClass();
$langConfig = new \stdClass;

// Idioma setado para ser exibido
if((isset($showLang) && $showLang) || (isset($addItems) && in_array('language', $addItems))){
    $langConfigDesk->text_style = "";
    $langConfigMobile->text_style = "";
    $langConfig->langItemStyle = "";
    // estilo do texto no hover
    $langConfig->langItemStyleHover = "";

    // ------------------------ DESKTOP --------------------- //
        if(isset($langParams->display_location)){
            $langConfig->displayLocation = $langParams->display_location;
        }else{
            $langConfig->displayLocation = 'main';
        }
        $langConfigDesk->dropdown = $langCustomization->dropdown;
        $langConfigDesk->enable_globe = $langCustomization->enable_globe;
        $langConfigDesk->show_active = $langCustomization->show_active;
        $langConfigDesk->language_name = $langCustomization->language_name;
        $langConfigDesk->image = $langCustomization->image;
        $langConfigDesk->inline = $langCustomization->inline;

        if($langCustomization->language_name){
            $langConfigDesk->text_alignment = $langCustomization->language_text_alignment_mobile;
            $langConfigDesk->text_style .= NoBossUtilFonts::importNobossfontlist($langCustomization->language_text_font);
            $langConfigDesk->text_style .= " text-transform: " . $langCustomization->language_text_transform . "; ";
            // pega a cor definida no modulo ou a cor primaria do template
            $langCustomization->language_text_color = !empty($langCustomization->language_text_color) ? $langCustomization->language_text_color : $tmplPrimaryColor;
            $langConfigDesk->text_style .= " text-align: {$langCustomization->language_text_alignment}; ";
            $langConfigDesk->text_style .= " color: " . $langCustomization->language_text_color . "; ";
            $inputSize = $langCustomization->language_text_size;
            if(!empty($inputSize)){
                $inputSizeEm = $inputSize/16;
                $langConfigDesk->text_style .= " font-size: {$inputSize}px; font-size: {$inputSizeEm}em;";
            }
            // pega a cor definida no modulo ou a cor primaria do template
            $langCustomization->language_color_hover = !empty($langCustomization->language_color_hover) ? $langCustomization->language_color_hover : $tmplPrimaryColor;
            $langConfig->langItemStyleHover .= !empty($langCustomization->language_color_hover) ? "color: {$langCustomization->language_color_hover} !important;" : "";
        }
        // estilo do link
        $langConfigDesk->space = ' padding: ' . implode(' ', $langCustomization->space) . '; ';
        $langConfigDesk->lang_item_space = "";
        $langConfigDesk->lang_item_space .= ' padding: ' . implode(' ', $langCustomization->items_inner_space) . '; ';
        $langConfigDesk->lang_item_space .= ' margin: ' . implode(' ', $langCustomization->items_outer_space) . '; ';
    // ------------------------ DESKTOP --------------------- //
    
    // estilo da lista de idiomas
    $langConfigDesk->lang_list_style = "";
    $langListStyleHover = "";
    if($langCustomization->dropdown){
        // pega a cor definida no modulo ou a cor primaria do template
        $langCustomization->list_selector_color = !empty($langCustomization->list_selector_color) ? $langCustomization->list_selector_color : $tmplPrimaryColor;
        $langConfigDesk->list_selector_color = "color: {$langCustomization->list_selector_color}; ";

        // pega a cor definida no modulo ou a cor primaria do template
        $langCustomization->list_items_color = !empty($langCustomization->list_items_color) ? $langCustomization->list_items_color : $tmplPrimaryColor;
        $langConfigDesk->lang_list_style .= !empty($langCustomization->list_items_color) ? " color: " . $langCustomization->list_items_color . ";" : "";
        
        // pega a cor definida no modulo ou a cor primaria do template
        $langCustomization->list_background_color = !empty($langCustomization->list_background_color) ? $langCustomization->list_background_color : $tmplPrimaryColor;
        $langConfigDesk->lang_list_style .= !empty($langCustomization->list_background_color) ? " background-color: " . $langCustomization->list_background_color . ";" : "";
        // pega a cor definida no modulo ou a cor secundaria do template
        $langCustomization->list_text_color_hover = !empty($langCustomization->list_text_color_hover) ? $langCustomization->list_text_color_hover : $tmplSecondaryColor;
        $langListStyleHover .= !empty($langCustomization->list_text_color_hover) ? "color: {$langCustomization->list_text_color_hover} !important;" : "";
        // espacamento da lista
        $langConfigDesk->lang_list_style .= ' padding: ' . implode(' ', $langCustomization->list_items_space) . '; ';
    }
    if(!$langCustomization->dropdown || !$langCustomization->dropdown_mobile){
        // verifica se foi definido cor de fundo
        if($langCustomization->show_language_background && !empty($langCustomization->language_background)){
            $langConfig->langItemStyle .= " background-color: " . $langCustomization->language_background . "; ";
        }
        // verifica se foi definido borda
        // pega a cor definida no modulo ou a cor primaria do template
        $langCustomization->language_border_color = !empty($langCustomization->language_border_color) ? $langCustomization->language_border_color : $tmplPrimaryColor;
        if($langCustomization->show_language_border){
            $langConfig->langItemStyle .= "border-style: solid; border-width: 1px; border-color: {$langCustomization->language_border_color};";
        }
        // verifica se foi definido border radius
        if($langCustomization->show_language_border_radius){
            $langConfig->langItemStyle .= " border-radius: " . $langCustomization->language_border_radius . "px;";
        }
        if($langCustomization->enable_language_hover){
            // pega a cor definida no modulo ou a cor secundaria do template
            $langCustomization->language_background_hover = !empty($langCustomization->language_background_hover) ? $langCustomization->language_background_hover : $tmplSecondaryColor;
            $langConfig->langItemStyleHover .= !empty($langCustomization->language_background_hover) ? "background-color: {$langCustomization->language_background_hover} !important;" : "";
            // pega a cor definida no modulo ou a cor secundaria do template
            $langCustomization->language_border_color_hover = !empty($langCustomization->language_border_color_hover) ? $langCustomization->language_border_color_hover : $tmplSecondaryColor;
            $langConfig->langItemStyleHover .= !empty($langCustomization->language_border_color_hover) ? "border-color: {$langCustomization->language_border_color_hover} !important;" : "";
        }
    }

    // ------------------------ MOBILE --------------------- //
        $langConfig->showLanguageMobile = $langParams->show_on_mobile;
        // guarda se deve ser exibido dentro do menu no mobile
        $langConfig->langShowInsideMenu = $langConfig->showLanguageMobile ? $langCustomization->show_inside_menu : false;
        // guarda se deve ser exibido antes ou depois dos itens de menu
        $langConfig->langShowItem = $langCustomization->show_item;

        $langConfigMobile->dropdown = $langConfig->langShowInsideMenu ? $langCustomization->dropdown_mobile : true;
        $langConfigMobile->enable_globe = $langCustomization->enable_globe_mobile;
        $langConfigMobile->show_active = $langCustomization->show_active_mobile;
        $langConfigMobile->language_name = $langCustomization->language_name_mobile;
        $langConfigMobile->image = $langCustomization->image_mobile;
        $langConfigMobile->inline = $langCustomization->inline_mobile;
        $langConfigMobile->intro_text = $langCustomization->intro_text;
        $langConfigMobile->space = ' padding: ' . implode(' ', $langCustomization->space_mobile) . '; ';

        // Lista 
        $langConfigMobile->lang_list_style = "";
        $langConfigMobile->lang_list_style .= "background-color: {$langCustomization->list_background_color_mobile};";
        $langConfigMobile->lang_list_style .= ' padding: ' . implode(' ', $langCustomization->list_items_space_mobile) . '; ';
        // pega a cor definida no modulo ou a cor primaria do template
        $langCustomization->list_selector_color_mobile = !empty($langCustomization->list_selector_color_mobile) ? $langCustomization->list_selector_color_mobile : $tmplPrimaryColor;
        $langConfigMobile->list_selector_color = "color: {$langCustomization->list_selector_color_mobile}; ";

        // pega a cor definida no modulo ou a cor primaria do template
        $langCustomization->list_items_color_mobile = !empty($langCustomization->list_items_color_mobile) ? $langCustomization->list_items_color_mobile : $tmplPrimaryColor;
        $langConfigMobile->lang_list_style .= !empty($langCustomization->list_items_color_mobile) ? " color: " . $langCustomization->list_items_color_mobile . ";" : "";
        
        // Itens 
        $langConfigMobile->text_alignment = $langCustomization->language_text_alignment_mobile;

        $langCustomization->language_text_color_mobile = !empty($langCustomization->language_text_color_mobile) ? $langCustomization->language_text_color_mobile : $tmplPrimaryColor;
        $langConfigMobile->text_style .= " text-transform: " . $langCustomization->language_text_transform_mobile . "; ";
        $langConfigMobile->text_style .= " color: " . $langCustomization->language_text_color_mobile . "; ";
        $inputSize = $langCustomization->language_text_size_mobile;
        if(!empty($inputSize)){
            $inputSizeEm = $inputSize/16;
            $langConfigMobile->text_style .= " font-size: {$inputSize}px; font-size: {$inputSizeEm}em;";
        }
        $langConfigMobile->lang_item_space = "";
        $langConfigMobile->lang_item_space .= ' padding: ' . implode(' ', $langCustomization->items_inner_space_mobile) . '; ';
        $langConfigMobile->lang_item_space .= ' margin: ' . implode(' ', $langCustomization->items_outer_space_mobile) . '; ';            

    // ------------------------ MOBILE --------------------- //
} 
// TODO: FIM - IDIOMA

// Define prefixo a ser utilizado na inserção de codigos inline para CSS e JS
$prefixCodeJsAndCss = "[module-id={$module->name}_{$module->id}]";

// Obtem informacoes de codigos JS e CSS a serem inseridos
$loadJs	 		= '1';
$loadCss 		= '1';
$overwritingJs	= (!empty($params->get('overwriting_js'))) ? rtrim($params->get('overwriting_js')) : '';
$overwritingCss	= (!empty($params->get('overwriting_css'))) ? rtrim($params->get('overwriting_css')) : '';

// Instancia objeto passando o nome da extensao com prefixo (ex: 'mod_nobossbanners')
$assetsObject = new NoBossUtilLoadExtensionAssets($extensionName, $prefixCodeJsAndCss);

// Adiciona arquivos e codigos JS (se definido para exibir)
$assetsObject->loadJs($loadJs, array('code' => $overwritingJs));

// Adiciona arquivos e codigos CSS (se definido para carregar)
$assetsObject->loadCss($loadCss, array('code' => $overwritingCss));

// Inclue família de fonte 
$assetsObject->loadFamilyIcons('material-icons');

// Renderiza o arquivo com os estilos
require JModuleHelper::getLayoutPath($extensionName, 'style/default');
// Renderiza o modulo
require JModuleHelper::getLayoutPath($extensionName, 'theme/default');
// Renderiza o header mobile 
require JModuleHelper::getLayoutPath($extensionName, 'theme/default_mobile');



