<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Library
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2024 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

namespace Noboss\Library\Form\Field;

use Joomla\CMS\Form\Field\RadioField;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Form\FormHelper;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

//TODO: no futuro unificar esse field com o 'NbRadioButtons' como um unico chamado 'NbRadioTheme'

// Sobreescreve o field do joomla para permitir o uso facilitado de exibicao modelos de dots, preenchendo automaticamente campos de personalizacao
class NbRadioDotsField extends RadioField{

	protected function getInput() {
        $app = Factory::getApplication();
        $wa = $app->getDocument()->getWebAssetManager();

        // Seta classe para ser inserida no fieldset
        $this->class = "nobossradiotheme";
        
        // CSS e JS do field
		$wa->registerAndUseStyle('nobossradiotheme', Uri::root()."libraries/noboss/src/Form/Field/assets/stylesheets/css/nobossradiotheme.min.css");
        $wa->registerAndUseScript('nobossradiotheme', Uri::root()."libraries/noboss/src/Form/Field/assets/js/min/nobossradiotheme.min.js");
        
        return parent::getInput();
	}

    protected function getOptions(){
		$options = array();   

        // Percorre cada option para tratamento
		foreach ($this->element->xpath('option') as $option){
            // Valor que contem referencia da url da imagem
            $value = (string) $option['value'];

            // Tamanho
            $styleSize = "width: 90px; height: 40px;";
			
            // Opcao manual
            if($value == 'manual'){
                $contentHtml = "<div class=\"nobossradiotheme__radio nobossradiotheme__manual\" style=\"{$styleSize}\">".Text::_('NOBOSS_EXTENSIONS_BUTTONS_THEME_OPT_MANUAL')."</div>";
            }
            // Imagem
            else{
                $urlImgDot = Uri::root()."libraries/noboss/src/Form/Field/assets/images/nbradiodots/{$value}.png";
                $contentHtml = "<div class=\"nobossradiotheme__radio\" style=\"{$styleSize}\"
                                    data-dots_border_radius_size=\"".$option['dots_border_radius_size']."\"
                                    data-dots_spacing_items=\"".$option['dots_spacing_items']."\"
                                    data-dots_size=\"".$option['dots_size']."\">
                                        <img style=\"{$styleSize}\" src=\"{$urlImgDot}\"/>
                                </div>";
            }

			$disabled = (string) $option['disabled'];
			$disabled = ($disabled == 'true' || $disabled == 'disabled' || $disabled == '1');
			$disabled = $disabled || ($this->readonly && $value != $this->value);

			$checked = (string) $option['checked'];
			$checked = ($checked == 'true' || $checked == 'checked' || $checked == '1');

			$tmp = array(
					'value'    => $value,
					'text'     => $contentHtml,
					'disable'  => $disabled,
					'class'    => (string) $option['class'],
					'checked'  => $checked,
			);

			if ((string) $option['showon']){
				$tmp['optionattr'] = " data-showon='" .
					json_encode(
						FormHelper::parseShowOnConditions((string) $option['showon'], $this->formControl, $this->group)
						)
					. "'";
			}
			
			$options[] = (object) $tmp;
		}

		reset($options);
        
        // echo '<pre>';
        // var_dump($options);
        // exit;

		return $options;

    }
}
